# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: spacex/api/device/wifi.proto
# Protobuf Python Version: 5.29.3
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    5,
    29,
    3,
    '',
    'spacex/api/device/wifi.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from spacex.api.device import common_pb2 as spacex_dot_api_dot_device_dot_common__pb2
from spacex.api.device import wifi_config_pb2 as spacex_dot_api_dot_device_dot_wifi__config__pb2
from spacex.api.device import wifi_util_pb2 as spacex_dot_api_dot_device_dot_wifi__util__pb2
from spacex.api.telemetron.public.common import time_pb2 as spacex_dot_api_dot_telemetron_dot_public_dot_common_dot_time__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cspacex/api/device/wifi.proto\x12\x11SpaceX.API.Device\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1espacex/api/device/common.proto\x1a#spacex/api/device/wifi_config.proto\x1a!spacex/api/device/wifi_util.proto\x1a.spacex/api/telemetron/public/common/time.proto\"F\n\x0bWifiClients\x12\x37\n\x07\x63lients\x18\x01 \x03(\x0b\x32\x1d.SpaceX.API.Device.WifiClientR\x07\x63lients\"\xb5\x02\n\x0cToController\x12\x1f\n\x0b\x61pi_version\x18\x04 \x01(\x05R\napiVersion\x12:\n\x07\x63lients\x18\x01 \x01(\x0b\x32\x1e.SpaceX.API.Device.WifiClientsH\x00R\x07\x63lients\x12>\n\tmesh_join\x18\x02 \x01(\x0b\x32\x1f.SpaceX.API.Device.WifiMeshJoinH\x00R\x08meshJoin\x12;\n\x06status\x18\x03 \x01(\x0b\x32!.SpaceX.API.Device.WifiMeshStatusH\x00R\x06status\x12@\n\tspeedtest\x18\x05 \x01(\x0b\x32 .SpaceX.API.Device.MeshSpeedtestH\x00R\tspeedtestB\t\n\x07message\"\xda\x01\n\x0cWifiMeshJoin\x12 \n\x0bincarnation\x18\x01 \x01(\x04R\x0bincarnation\x12)\n\x10hardware_version\x18\x02 \x01(\tR\x0fhardwareVersion\x12,\n\x12supports_5ghz_high\x18\x03 \x01(\x08R\x10supports5ghzHigh\x12O\n\x0esiteSurveyScan\x18\x04 \x03(\x0b\x32\'.SpaceX.API.Device.WifiSiteSurveyResultR\x0esiteSurveyScan\"\x90\x03\n\x0eWifiMeshStatus\x12)\n\x10software_version\x18\x05 \x01(\tR\x0fsoftwareVersion\x12\x17\n\x07mac_lan\x18\x06 \x01(\tR\x06macLan\x12\x30\n\x14source_mac_addresses\x18\x07 \x03(\tR\x12sourceMacAddresses\x12\x37\n\x07\x63lients\x18\x02 \x03(\x0b\x32\x1d.SpaceX.API.Device.WifiClientR\x07\x63lients\x12\x45\n\x08\x62ss_list\x18\x03 \x03(\x0b\x32*.SpaceX.API.Device.InflatedBasicServiceSetR\x07\x62ssList\x12)\n\x10hardware_version\x18\x04 \x01(\tR\x0fhardwareVersion\x12%\n\x0e\x62\x61\x63khaul_bssid\x18\x08 \x01(\tR\rbackhaulBssid\x12\x36\n\x17\x62\x61\x63khaul_est_preference\x18\t \x01(\rR\x15\x62\x61\x63khaulEstPreference\"\x16\n\x14MeshSpeedtestRequest\"\xb1\x01\n\rMeshSpeedtest\x12*\n\x11upload_start_time\x18\x01 \x01(\x03R\x0fuploadStartTime\x12.\n\x13\x64ownload_start_time\x18\x02 \x01(\x03R\x11\x64ownloadStartTime\x12\x1f\n\x0bupload_mbps\x18\x03 \x01(\x02R\nuploadMbps\x12#\n\rdownload_mbps\x18\x04 \x01(\x02R\x0c\x64ownloadMbps\"\xcc\x02\n\x14WifiSiteSurveyResult\x12\x12\n\x04rssi\x18\x01 \x01(\x02R\x04rssi\x12\x18\n\x07\x63hannel\x18\x02 \x01(\rR\x07\x63hannel\x12\x12\n\x04ssid\x18\x03 \x01(\tR\x04ssid\x12;\n\x08security\x18\x04 \x01(\x0e\x32\x1f.SpaceX.API.Device.WifiSecurityR\x08security\x12@\n\rwireless_mode\x18\x05 \x01(\x0e\x32\x1b.SpaceX.API.Device.WifiModeR\x0cwirelessMode\x12\x32\n\x05iface\x18\x06 \x01(\x0e\x32\x1c.SpaceX.API.Device.IfaceTypeR\x05iface\x12\x1f\n\x0bmac_address\x18\x07 \x01(\tR\nmacAddress\x12\x1e\n\x0b\x65st_rx_rate\x18\x08 \x01(\x02R\testRxRate\"\xb3\x01\n\x14WifiGlobalMeshStatus\x12)\n\x10hardware_version\x18\x01 \x01(\tR\x0fhardwareVersion\x12)\n\x10software_version\x18\x02 \x01(\tR\x0fsoftwareVersion\x12\x45\n\x08\x62ss_list\x18\x03 \x03(\x0b\x32*.SpaceX.API.Device.InflatedBasicServiceSetR\x07\x62ssList\"v\n\x0f\x42\x61\x63khaulRequest\x12%\n\x0eretry_backhaul\x18\x01 \x01(\x08R\rretryBackhaul\x12<\n\ngolden_bss\x18\x02 \x01(\x0b\x32\x1d.SpaceX.API.Device.WifiConfigR\tgoldenBss\"\x94\x04\n\x0e\x46romController\x12\x1f\n\x0b\x61pi_version\x18\x03 \x01(\x05R\napiVersion\x12@\n\x0bwifi_config\x18\x01 \x01(\x0b\x32\x1d.SpaceX.API.Device.WifiConfigH\x00R\nwifiConfig\x12]\n\x14steer_client_request\x18\x02 \x01(\x0b\x32%.SpaceX.API.Device.SteerClientRequestB\x02\x18\x01H\x00R\x12steerClientRequest\x12\x41\n\x06status\x18\x04 \x01(\x0b\x32\'.SpaceX.API.Device.WifiGlobalMeshStatusH\x00R\x06status\x12O\n\x10\x62\x61\x63khaul_request\x18\x05 \x01(\x0b\x32\".SpaceX.API.Device.BackhaulRequestH\x00R\x0f\x62\x61\x63khaulRequest\x12R\n\x0fstart_speedtest\x18\x06 \x01(\x0b\x32\'.SpaceX.API.Device.MeshSpeedtestRequestH\x00R\x0estartSpeedtest\x12M\n\x10wifi_btm_request\x18\x07 \x01(\x0b\x32!.SpaceX.API.Device.WifiBtmRequestH\x00R\x0ewifiBtmRequestB\t\n\x07message\"\xdc\x01\n\x12SteerClientRequest\x12*\n\x0f\x63lient_mac_addr\x18\x01 \x01(\tB\x02\x18\x01R\rclientMacAddr\x12O\n\x07targets\x18\x02 \x03(\x0b\x32\x31.SpaceX.API.Device.SteerClientRequest.SteerTargetB\x02\x18\x01R\x07targets\x1a\x45\n\x0bSteerTarget\x12\x18\n\x05\x62ssid\x18\x01 \x01(\tB\x02\x18\x01R\x05\x62ssid\x12\x1c\n\x07\x63hannel\x18\x02 \x01(\x05\x42\x02\x18\x01R\x07\x63hannel:\x02\x18\x01\"\xb9\x02\n\x0eWifiBtmRequest\x12;\n\x1a\x62ss_termination_duration_m\x18\x05 \x01(\rR\x17\x62ssTerminationDurationM\x12\x1d\n\npeer_bssid\x18\x01 \x01(\tR\tpeerBssid\x12Y\n\x0fneighbor_report\x18\x04 \x03(\x0b\x32\x30.SpaceX.API.Device.WifiBtmRequest.NeighborReportR\x0eneighborReport\x1a@\n\x0eNeighborReport\x12\x14\n\x05\x62ssid\x18\x01 \x01(\tR\x05\x62ssid\x12\x18\n\x07\x63hannel\x18\x02 \x01(\rR\x07\x63hannelJ\x04\x08\x02\x10\x03J\x04\x08\x03\x10\x04R\x0crequest_modeR\x14termination_duration\"\xa6\x03\n\x0cWifiSelfTest\x12#\n\rtotal_success\x18\x01 \x01(\x08R\x0ctotalSuccess\x12@\n\x05\x66used\x18\x02 \x01(\x0b\x32*.SpaceX.API.Device.WifiSelfTest.TestResultR\x05\x66used\x12\x45\n\x08\x65th_phys\x18\x03 \x03(\x0b\x32*.SpaceX.API.Device.WifiSelfTest.TestResultR\x07\x65thPhys\x12>\n\x04pcis\x18\x04 \x03(\x0b\x32*.SpaceX.API.Device.WifiSelfTest.TestResultR\x04pcis\x12\x45\n\x08\x62l2_prod\x18\x05 \x01(\x0b\x32*.SpaceX.API.Device.WifiSelfTest.TestResultR\x07\x62l2Prod\x1a\x61\n\nTestResult\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x18\n\x07success\x18\x02 \x01(\x08R\x07success\x12%\n\x0e\x66\x61ilure_reason\x18\x03 \x01(\tR\rfailureReason\"V\n\x14WifiSetConfigRequest\x12>\n\x0bwifi_config\x18\x01 \x01(\x0b\x32\x1d.SpaceX.API.Device.WifiConfigR\nwifiConfig\"f\n\x15WifiSetConfigResponse\x12M\n\x13updated_wifi_config\x18\x01 \x01(\x0b\x32\x1d.SpaceX.API.Device.WifiConfigR\x11updatedWifiConfig\"\x16\n\x14WifiGetConfigRequest\"W\n\x15WifiGetConfigResponse\x12>\n\x0bwifi_config\x18\x01 \x01(\x0b\x32\x1d.SpaceX.API.Device.WifiConfigR\nwifiConfig\"m\n\x1dWifiSetMeshDeviceTrustRequest\x12\x1b\n\tdevice_id\x18\x01 \x01(\tR\x08\x64\x65viceId\x12/\n\x04\x61uth\x18\x02 \x01(\x0e\x32\x1b.SpaceX.API.Device.MeshAuthR\x04\x61uth\" \n\x1eWifiSetMeshDeviceTrustResponse\"w\n\x18WifiSetMeshConfigRequest\x12>\n\x0bmesh_config\x18\x01 \x01(\x0b\x32\x1d.SpaceX.API.Device.MeshConfigR\nmeshConfig\x12\x1b\n\tdevice_id\x18\x02 \x01(\tR\x08\x64\x65viceId\"\x1b\n\x19WifiSetMeshConfigResponse\"\x17\n\x15WifiGetClientsRequest\"\x9e\x01\n\x16WifiGetClientsResponse\x12\x37\n\x07\x63lients\x18\x01 \x03(\x0b\x32\x1d.SpaceX.API.Device.WifiClientR\x07\x63lients\x12(\n\x10has_client_index\x18\x02 \x01(\x08R\x0ehasClientIndex\x12!\n\x0c\x63lient_index\x18\x03 \x01(\x05R\x0b\x63lientIndex\"_\n\x1bWifiGetClientHistoryRequest\x12#\n\x0bmac_address\x18\x01 \x01(\tB\x02\x18\x01R\nmacAddress\x12\x1b\n\tclient_id\x18\x02 \x01(\rR\x08\x63lientId\"\xa7\x03\n\x1cWifiGetClientHistoryResponse\x12\x18\n\x07\x63urrent\x18\x01 \x01(\x04R\x07\x63urrent\x12,\n\x12tx_throughput_mbps\x18\x02 \x03(\x02R\x10txThroughputMbps\x12,\n\x12rx_throughput_mbps\x18\x03 \x03(\x02R\x10rxThroughputMbps\x12p\n\x12throughput_limited\x18\x04 \x03(\x0e\x32\x41.SpaceX.API.Device.WifiGetClientHistoryResponse.WifiLimitedReasonR\x11throughputLimited\x12 \n\x0crx_rate_mbps\x18\x05 \x03(\x02R\nrxRateMbps\x12\x12\n\x04rssi\x18\x06 \x01(\x0cR\x04rssi\"i\n\x11WifiLimitedReason\x12\x11\n\rLIMIT_UNKNOWN\x10\x00\x12\x0e\n\nLIMIT_NONE\x10\x01\x12\x16\n\x12LIMIT_UNCLASSIFIED\x10\x02\x12\x19\n\x15LIMIT_DROPPED_PACKETS\x10\x03\"!\n\x1fWifiSetAviationConformedRequest\"\x82\x01\n\x16WifiGetHistoryResponse\x12\x18\n\x07\x63urrent\x18\x01 \x01(\x04R\x07\x63urrent\x12%\n\x0eping_drop_rate\x18\xe9\x07 \x03(\x02R\x0cpingDropRate\x12\'\n\x0fping_latency_ms\x18\xea\x07 \x03(\x02R\rpingLatencyMs\"T\n\x1bWifiNewClientConnectedEvent\x12\x35\n\x06\x63lient\x18\x01 \x01(\x0b\x32\x1d.SpaceX.API.Device.WifiClientR\x06\x63lient\"\xba\x1b\n\nWifiClient\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x1d\n\ngiven_name\x18\x1f \x01(\tR\tgivenName\x12\x16\n\x06\x64omain\x18\x16 \x01(\tR\x06\x64omain\x12\x1f\n\x0bmac_address\x18\x02 \x01(\tR\nmacAddress\x12\x1d\n\nip_address\x18\x03 \x01(\tR\tipAddress\x12*\n\x11\x64hcp_lease_active\x18. \x01(\x08R\x0f\x64hcpLeaseActive\x12,\n\x12\x64hcp_lease_renewed\x18/ \x01(\x08R\x10\x64hcpLeaseRenewed\x12%\n\x0eipv6_addresses\x18) \x03(\tR\ripv6Addresses\x12\'\n\x0fsignal_strength\x18\x04 \x01(\x02R\x0esignalStrength\x12#\n\rchannel_width\x18\x0c \x01(\rR\x0c\x63hannelWidth\x12@\n\x08rx_stats\x18\x05 \x01(\x0b\x32%.SpaceX.API.Device.WifiClient.RxStatsR\x07rxStats\x12@\n\x08tx_stats\x18\x06 \x01(\x0b\x32%.SpaceX.API.Device.WifiClient.TxStatsR\x07txStats\x12*\n\x11\x61ssociated_time_s\x18\x07 \x01(\rR\x0f\x61ssociatedTimeS\x12#\n\x0eno_data_idle_s\x18- \x01(\rR\x0bnoDataIdleS\x12\x19\n\x08mode_str\x18\x08 \x01(\tR\x07modeStr\x12=\n\x05iface\x18\t \x01(\x0e\x32\'.SpaceX.API.Device.WifiClient.InterfaceR\x05iface\x12\x1d\n\niface_name\x18\x1a \x01(\tR\tifaceName\x12\x10\n\x03snr\x18\n \x01(\x02R\x03snr\x12\x16\n\x06psmode\x18\x0b \x01(\x05R\x06psmode\x12\x30\n\x14upstream_mac_address\x18\r \x01(\tR\x12upstreamMacAddress\x12\x36\n\x04role\x18\x0e \x01(\x0e\x32\".SpaceX.API.Device.WifiClient.RoleR\x04role\x12\x1b\n\tdevice_id\x18\x0f \x01(\tR\x08\x64\x65viceId\x12\x1d\n\nswq_checks\x18\x10 \x01(\rR\tswqChecks\x12/\n\x14swq_checks_non_empty\x18\x11 \x01(\rR\x11swqChecksNonEmpty\x12&\n\x0fmib_steer_state\x18\x12 \x01(\rR\rmibSteerState\x12(\n\x10mib_steer_method\x18\x13 \x01(\rR\x0emibSteerMethod\x12!\n\x0c\x62tm_requests\x18\x14 \x01(\rR\x0b\x62tmRequests\x12\x30\n\x14\x62tm_requests_success\x18\x15 \x01(\rR\x12\x62tmRequestsSuccess\x12\x1f\n\x0bsteer_state\x18\x1e \x01(\rR\nsteerState\x12\x38\n\x19steer_req_success_last_1h\x18\x1b \x01(\rR\x15steerReqSuccessLast1h\x12\x32\n\x16steer_req_fail_last_1h\x18\x1c \x01(\rR\x12steerReqFailLast1h\x12\x46\n!steer_req_fail_and_dissoc_last_1h\x18\x1d \x01(\rR\x1bsteerReqFailAndDissocLast1h\x12%\n\x0e\x64ot11v_support\x18\x17 \x01(\x08R\rdot11vSupport\x12\x30\n\x14hops_from_controller\x18  \x01(\rR\x12hopsFromController\x12\x45\n est_tx_rate_mbps_from_controller\x18! \x01(\x02R\x1b\x65stTxRateMbpsFromController\x12\x45\n est_rx_rate_mbps_from_controller\x18\" \x01(\x02R\x1b\x65stRxRateMbpsFromController\x12)\n\x10hardware_version\x18% \x01(\tR\x0fhardwareVersion\x12)\n\x10software_version\x18& \x01(\tR\x0fsoftwareVersion\x12\x1f\n\x0b\x61pi_version\x18\' \x01(\rR\napiVersion\x12L\n\x0cping_metrics\x18( \x01(\x0b\x32).SpaceX.API.Device.WifiClient.PingMetricsR\x0bpingMetrics\x12\x18\n\x07\x62locked\x18* \x01(\x08R\x07\x62locked\x12\x1b\n\tclient_id\x18+ \x01(\rR\x08\x63lientId\x12L\n\x0c\x66qcodel_info\x18, \x01(\x0b\x32).SpaceX.API.Device.WifiClient.FqcodelInfoR\x0b\x66qcodelInfo\x1a\x89\x04\n\x07RxStats\x12\x14\n\x05\x62ytes\x18\x01 \x01(\x04R\x05\x62ytes\x12!\n\x0c\x63ount_errors\x18\x02 \x01(\x04R\x0b\x63ountErrors\x12\x19\n\x08phy_mode\x18\r \x01(\rR\x07phyMode\x12\x10\n\x03nss\x18\x03 \x01(\x05R\x03nss\x12\x1b\n\trate_mbps\x18\x08 \x01(\rR\x08rateMbps\x12+\n\x12rate_mbps_last_30s\x18\x0e \x01(\x02R\x0frateMbpsLast30s\x12+\n\x12rate_mbps_last_15s\x18\x0f \x01(\x02R\x0frateMbpsLast15s\x12\x10\n\x03mcs\x18\x05 \x01(\rR\x03mcs\x12\x1c\n\tbandwidth\x18\x06 \x01(\rR\tbandwidth\x12\x19\n\x08guard_ns\x18\x07 \x01(\rR\x07guardNs\x12\x37\n\x18\x61irtime_fraction_last_1s\x18\t \x01(\x02R\x15\x61irtimeFractionLast1s\x12\'\n\x0fsampled_packets\x18\n \x01(\rR\x0esampledPackets\x12\x36\n\x17sampled_packets_retried\x18\x0b \x01(\rR\x15sampledPacketsRetried\x12\x36\n\x17sampled_packets_dropped\x18\x0c \x01(\rR\x15sampledPacketsDroppedJ\x04\x08\x04\x10\x05\x1a\xf2\x02\n\x07TxStats\x12\x14\n\x05\x62ytes\x18\x01 \x01(\x04R\x05\x62ytes\x12#\n\rsuccess_bytes\x18\x02 \x01(\x04R\x0csuccessBytes\x12\x19\n\x08phy_mode\x18\n \x01(\rR\x07phyMode\x12\x10\n\x03nss\x18\x03 \x01(\x05R\x03nss\x12\x1b\n\trate_mbps\x18\x08 \x01(\rR\x08rateMbps\x12+\n\x12rate_mbps_last_30s\x18\x0b \x01(\x02R\x0frateMbpsLast30s\x12+\n\x12rate_mbps_last_15s\x18\x0c \x01(\x02R\x0frateMbpsLast15s\x12\x10\n\x03mcs\x18\x05 \x01(\rR\x03mcs\x12\x1c\n\tbandwidth\x18\x06 \x01(\rR\tbandwidth\x12\x19\n\x08guard_ns\x18\x07 \x01(\rR\x07guardNs\x12\x37\n\x18\x61irtime_fraction_last_1s\x18\t \x01(\x02R\x15\x61irtimeFractionLast1sJ\x04\x08\x04\x10\x05\x1a\xa8\x01\n\x0bPingMetrics\x12+\n\x12in_unhappy_hour_2s\x18\x01 \x01(\x08R\x0finUnhappyHour2s\x12+\n\x12in_unhappy_hour_5s\x18\x02 \x01(\x08R\x0finUnhappyHour5s\x12 \n\x0c\x64rop_rate_5m\x18\x03 \x01(\x02R\ndropRate5m\x12\x1d\n\nlatency_5m\x18\x04 \x01(\x02R\tlatency5m\x1a\x94\x03\n\x0b\x46qcodelInfo\x12 \n\x0c\x65nqs_hi_prio\x18\x01 \x01(\x04R\nenqsHiPrio\x12!\n\x0c\x65nqs_fqcodel\x18\x02 \x01(\x04R\x0b\x65nqsFqcodel\x12\x19\n\x08\x65nqs_new\x18\x03 \x01(\x04R\x07\x65nqsNew\x12\x19\n\x08\x65nqs_old\x18\x04 \x01(\x04R\x07\x65nqsOld\x12!\n\x0c\x65nqs_dropped\x18\x05 \x01(\x04R\x0b\x65nqsDropped\x12\x19\n\x08\x64\x65qs_new\x18\x06 \x01(\x04R\x07\x64\x65qsNew\x12\x19\n\x08\x64\x65qs_old\x18\x07 \x01(\x04R\x07\x64\x65qsOld\x12\"\n\rdeqs_flow_new\x18\x08 \x01(\x04R\x0b\x64\x65qsFlowNew\x12\x31\n\x15\x64\x65qs_flow_old_deficit\x18\t \x01(\x04R\x12\x64\x65qsFlowOldDeficit\x12\x37\n\x18\x64\x65qs_flow_old_starvation\x18\n \x01(\x04R\x15\x64\x65qsFlowOldStarvation\x12!\n\x0c\x64\x65qs_dropped\x18\x0b \x01(\x04R\x0b\x64\x65qsDropped\"M\n\tInterface\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x07\n\x03\x45TH\x10\x01\x12\x0b\n\x07RF_2GHZ\x10\x02\x12\x0b\n\x07RF_5GHZ\x10\x03\x12\x10\n\x0cRF_5GHZ_HIGH\x10\x04\"B\n\x04Role\x12\x10\n\x0cROLE_UNKNOWN\x10\x00\x12\n\n\x06\x43LIENT\x10\x01\x12\x0c\n\x08REPEATER\x10\x02\x12\x0e\n\nCONTROLLER\x10\x03\"\x8c\x01\n\x10WifiSetupRequest\x12\x12\n\x04skip\x18\x01 \x01(\x08R\x04skip\x12!\n\x0cnetwork_name\x18\x02 \x01(\tR\x0bnetworkName\x12)\n\x10network_password\x18\x03 \x01(\tR\x0fnetworkPassword\x12\x16\n\x06\x62ypass\x18\x04 \x01(\x08R\x06\x62ypass\"\x13\n\x11WifiSetupResponse\"\x95\x02\n\x0eWifiBandStatus\x12\x35\n\x17\x63han_busy_time_fraction\x18\x01 \x01(\x02R\x14\x63hanBusyTimeFraction\x12/\n\x14tx_air_time_fraction\x18\x02 \x01(\x02R\x11txAirTimeFraction\x12/\n\x14rx_air_time_fraction\x18\x03 \x01(\x02R\x11rxAirTimeFraction\x12\x33\n\x16obss_air_time_fraction\x18\x04 \x01(\x02R\x13obssAirTimeFraction\x12\x35\n\x17\x65\x64\x63\x63\x61_air_time_fraction\x18\x05 \x01(\x02R\x14\x65\x64\x63\x63\x61\x41irTimeFraction\"\xe1\x07\n\nWifiAlerts\x12)\n\x10thermal_throttle\x18\x01 \x01(\x08R\x0fthermalThrottle\x12\'\n\x0finstall_pending\x18\x02 \x01(\x08R\x0einstallPending\x12#\n\rfreshly_fused\x18\x03 \x01(\x08R\x0c\x66reshlyFused\x12.\n\x14lan_eth_slow_link_10\x18\x04 \x01(\x08R\x10lanEthSlowLink10\x12\x30\n\x15lan_eth_slow_link_100\x18\x05 \x01(\x08R\x11lanEthSlowLink100\x12\x35\n\x17wan_eth_poor_connection\x18\n \x01(\x08R\x14wanEthPoorConnection\x12?\n\x1cmesh_topology_changing_often\x18\x0b \x01(\x08R\x19meshTopologyChangingOften\x12\x38\n\x18mesh_unreliable_backhaul\x18\x0c \x01(\x08R\x16meshUnreliableBackhaul\x12\x34\n\x16radius_missing_process\x18\r \x01(\x08R\x14radiusMissingProcess\x12(\n\x10\x65th_switch_error\x18\x0e \x01(\x08R\x0e\x65thSwitchError\x12\x35\n\x17poe_on_dish_unreachable\x18\x0f \x01(\x08R\x14poeOnDishUnreachable\x12$\n\x0epoe_fuse_blown\x18\x10 \x01(\x08R\x0cpoeFuseBlown\x12\x34\n\x16poe_router_overcurrent\x18\x11 \x01(\x08R\x14poeRouterOvercurrent\x12\x35\n\x17poe_off_current_nominal\x18\x12 \x01(\x08R\x14poeOffCurrentNominal\x12.\n\x13poe_vin_overvoltage\x18\x13 \x01(\x08R\x11poeVinOvervoltage\x12\x30\n\x14poe_vin_undervoltage\x18\x14 \x01(\x08R\x12poeVinUndervoltageJ\x04\x08\x06\x10\x07J\x04\x08\x07\x10\x08J\x04\x08\x08\x10\tJ\x04\x08\t\x10\nR+inconsistent_2ghz_antennae_performance_15dbR+inconsistent_5ghz_antennae_performance_15dbR#poor_2ghz_antennae_performance_80dbR#poor_5ghz_antennae_performance_80db\"\xca\x0c\n\x15WifiGetStatusResponse\x12>\n\x0b\x64\x65vice_info\x18\x03 \x01(\x0b\x32\x1d.SpaceX.API.Device.DeviceInfoR\ndeviceInfo\x12\x41\n\x0c\x64\x65vice_state\x18\x04 \x01(\x0b\x32\x1e.SpaceX.API.Device.DeviceStateR\x0b\x64\x65viceState\x12\x34\n\x16\x63\x61ptive_portal_enabled\x18\x01 \x01(\x08R\x14\x63\x61ptivePortalEnabled\x12)\n\x10ipv4_wan_address\x18\xeb\x07 \x01(\tR\x0eipv4WanAddress\x12-\n\x12ipv6_wan_addresses\x18\xf9\x07 \x03(\tR\x10ipv6WanAddresses\x12%\n\x0eping_drop_rate\x18\xec\x07 \x01(\x02R\x0cpingDropRate\x12*\n\x11ping_drop_rate_5m\x18\xfd\x07 \x01(\x02R\x0epingDropRate5m\x12\'\n\x0fping_latency_ms\x18\xed\x07 \x01(\x02R\rpingLatencyMs\x12.\n\x13\x64ish_ping_drop_rate\x18\xf4\x07 \x01(\x02R\x10\x64ishPingDropRate\x12\x33\n\x16\x64ish_ping_drop_rate_5m\x18\xfa\x07 \x01(\x02R\x12\x64ishPingDropRate5m\x12\x30\n\x14\x64ish_ping_latency_ms\x18\xf5\x07 \x01(\x02R\x11\x64ishPingLatencyMs\x12,\n\x12pop_ping_drop_rate\x18\xf6\x07 \x01(\x02R\x0fpopPingDropRate\x12\x31\n\x15pop_ping_drop_rate_5m\x18\xfc\x07 \x01(\x02R\x11popPingDropRate5m\x12.\n\x13pop_ping_latency_ms\x18\xf7\x07 \x01(\x02R\x10popPingLatencyMs\x12L\n\x0erf_2ghz_status\x18\xf0\x07 \x01(\x0b\x32!.SpaceX.API.Device.WifiBandStatusB\x02\x18\x01R\x0crf2ghzStatus\x12L\n\x0erf_5ghz_status\x18\xf1\x07 \x01(\x0b\x32!.SpaceX.API.Device.WifiBandStatusB\x02\x18\x01R\x0crf5ghzStatus\x12\x36\n\x06\x61lerts\x18\xf2\x07 \x01(\x0b\x32\x1d.SpaceX.API.Device.WifiAlertsR\x06\x61lerts\x12 \n\x0bis_aviation\x18\xf3\x07 \x01(\x08R\nisAviation\x12\x36\n\x06\x63onfig\x18\xd0\x0f \x01(\x0b\x32\x1d.SpaceX.API.Device.WifiConfigR\x06\x63onfig\x12\x38\n\x07\x63lients\x18\xb8\x17 \x03(\x0b\x32\x1d.SpaceX.API.Device.WifiClientR\x07\x63lients\x12)\n\x10has_client_index\x18\xb9\x17 \x01(\x08R\x0ehasClientIndex\x12\"\n\x0c\x63lient_index\x18\xba\x17 \x01(\x05R\x0b\x63lientIndex\x12\x33\n\x15is_aviation_conformed\x18\xf8\x07 \x01(\x08R\x13isAviationConformed\x12\x45\n\x0cradius_stats\x18\xbb\x17 \x01(\x0b\x32!.SpaceX.API.Device.RadiusStatsMapR\x0bradiusStats\x12\x41\n\x0c\x64hcp_servers\x18\xfb\x07 \x03(\x0b\x32\x1d.SpaceX.API.Device.DhcpServerR\x0b\x64hcpServers\x12\x39\n\tpoe_stats\x18\xfe\x07 \x01(\x0b\x32\x1b.SpaceX.API.Device.PoeStatsR\x08poeStats\x12\x18\n\x07\x64ish_id\x18\xff\x07 \x01(\tR\x06\x64ishId\x12\x16\n\x06utc_ns\x18\x80\x08 \x01(\x03R\x05utcNs\x12_\n\x15software_update_stats\x18\x81\x08 \x01(\x0b\x32*.SpaceX.API.Device.WifiSoftwareUpdateStatsR\x13softwareUpdateStatsJ\x04\x08\x02\x10\x03J\x04\x08\x05\x10\x06J\x04\x08\x06\x10\x07J\x04\x08\x07\x10\x08J\x06\x08\xe9\x07\x10\xea\x07J\x06\x08\xea\x07\x10\xeb\x07J\x06\x08\xee\x07\x10\xef\x07J\x06\x08\xef\x07\x10\xf0\x07\"V\n\x17WifiAuthenticateRequest\x12;\n\tchallenge\x18\x01 \x01(\x0b\x32\x1d.SpaceX.API.Device.SignedDataR\tchallenge\"\x8e\x01\n\x18WifiAuthenticateResponse\x12\x38\n\x04wifi\x18\x01 \x01(\x0b\x32$.SpaceX.API.Device.ChallengeResponseR\x04wifi\x12\x38\n\x04\x64ish\x18\x02 \x01(\x0b\x32$.SpaceX.API.Device.ChallengeResponseR\x04\x64ish\"~\n\x17WifiAccountBondingEvent\x12\x17\n\x07\x64ish_id\x18\x01 \x01(\tR\x06\x64ishId\x12\x1f\n\x0bis_repeater\x18\x02 \x01(\x08R\nisRepeater\x12)\n\x10hardware_version\x18\x03 \x01(\tR\x0fhardwareVersion\"+\n\x10WifiNewPeerEvent\x12\x17\n\x07peer_id\x18\x01 \x01(\tR\x06peerId\"\xb5\x07\n\x0bPingMetrics\x12&\n\x0flatency_mean_ms\x18\x01 \x01(\x02R\rlatencyMeanMs\x12*\n\x11latency_stddev_ms\x18\x02 \x01(\x02R\x0flatencyStddevMs\x12+\n\x12latency_mean_ms_5m\x18\x03 \x01(\x02R\x0flatencyMeanMs5m\x12+\n\x12latency_mean_ms_1h\x18\x04 \x01(\x02R\x0flatencyMeanMs1h\x12/\n\x12latency_mean_ms_1d\x18\x05 \x01(\x02\x42\x02\x18\x01R\x0flatencyMeanMs1d\x12\x1b\n\tdrop_rate\x18\x06 \x01(\x02R\x08\x64ropRate\x12 \n\x0c\x64rop_rate_5m\x18\x07 \x01(\x02R\ndropRate5m\x12 \n\x0c\x64rop_rate_1h\x18\x08 \x01(\x02R\ndropRate1h\x12 \n\x0c\x64rop_rate_1d\x18\t \x01(\x02R\ndropRate1d\x12;\n\x1aseconds_since_last_success\x18\n \x01(\x02R\x17secondsSinceLastSuccess\x12>\n\x1cseconds_since_last_1s_outage\x18\x0b \x01(\x02R\x18secondsSinceLast1sOutage\x12>\n\x1cseconds_since_last_2s_outage\x18\x0f \x01(\x02R\x18secondsSinceLast2sOutage\x12>\n\x1cseconds_since_last_5s_outage\x18\x0c \x01(\x02R\x18secondsSinceLast5sOutage\x12@\n\x1dseconds_since_last_15s_outage\x18\x12 \x01(\x02R\x19secondsSinceLast15sOutage\x12@\n\x1dseconds_since_last_60s_outage\x18\x13 \x01(\x02R\x19secondsSinceLast60sOutage\x12\x42\n\x1eseconds_since_last_300s_outage\x18\x14 \x01(\x02R\x1asecondsSinceLast300sOutage\x12)\n\x11happy_hours_1s_1d\x18\r \x01(\x02R\x0ehappyHours1s1d\x12)\n\x11happy_hours_2s_1d\x18\x10 \x01(\x02R\x0ehappyHours2s1d\x12)\n\x11happy_hours_5s_1d\x18\x0e \x01(\x02R\x0ehappyHours5s1d\"\x1b\n\x19WifiGetPingMetricsRequest\"X\n\x1aWifiGetPingMetricsResponse\x12:\n\x08internet\x18\x01 \x01(\x0b\x32\x1e.SpaceX.API.Device.PingMetricsR\x08internet\"\xde\x01\n\x0bWifiNetwork\x12\x37\n\x04\x62\x61nd\x18\x01 \x01(\x0e\x32#.SpaceX.API.Device.WifiNetwork.BandR\x04\x62\x61nd\x12\x12\n\x04ssid\x18\x02 \x01(\tR\x04ssid\x12\x18\n\x07\x63hannel\x18\x03 \x01(\rR\x07\x63hannel\x12.\n\x13\x65ncryption_type_str\x18\x04 \x01(\tR\x11\x65ncryptionTypeStr\"8\n\x04\x42\x61nd\x12\x10\n\x0cWIFI_UNKNOWN\x10\x00\x12\x0f\n\x0bWIFI_2_4GHZ\x10\x01\x12\r\n\tWIFI_5GHZ\x10\x02\"\x83\x05\n\x13WifiPersistentStats\x12^\n\x14\x66\x61\x63tory_reset_button\x18\x01 \x01(\x0b\x32,.SpaceX.API.Device.WifiPersistentStats.EventR\x12\x66\x61\x63toryResetButton\x12g\n\x19\x66\x61\x63tory_reset_plug_unplug\x18\x02 \x01(\x0b\x32,.SpaceX.API.Device.WifiPersistentStats.EventR\x16\x66\x61\x63toryResetPlugUnplug\x12`\n\x15\x66\x61\x63tory_reset_command\x18\x03 \x01(\x0b\x32,.SpaceX.API.Device.WifiPersistentStats.EventR\x13\x66\x61\x63toryResetCommand\x12}\n%factory_reset_failed_load_wifi_config\x18\x04 \x01(\x0b\x32,.SpaceX.API.Device.WifiPersistentStats.EventR factoryResetFailedLoadWifiConfig\x12k\n\x1breboot_from_software_update\x18\x05 \x01(\x0b\x32,.SpaceX.API.Device.WifiPersistentStats.EventR\x18rebootFromSoftwareUpdate\x1aU\n\x05\x45vent\x12\x14\n\x05\x63ount\x18\x01 \x01(\rR\x05\x63ount\x12\x36\n\x17last_occurred_timestamp\x18\x02 \x01(\x03R\x15lastOccurredTimestamp\"^\n\x1eWifiGetPersistentStatsResponse\x12<\n\x05stats\x18\x01 \x01(\x0b\x32&.SpaceX.API.Device.WifiPersistentStatsR\x05stats\"\x83\x05\n\nRadioStats\x12\x36\n\x04\x62\x61nd\x18\x01 \x01(\x0e\x32\".SpaceX.API.Device.WifiConfig.BandR\x04\x62\x61nd\x12\x46\n\x08rx_stats\x18\x02 \x01(\x0b\x32+.SpaceX.API.Device.NetworkInterface.RxStatsR\x07rxStats\x12\x46\n\x08tx_stats\x18\x03 \x01(\x0b\x32+.SpaceX.API.Device.NetworkInterface.TxStatsR\x07txStats\x12R\n\x0ethermal_status\x18\x04 \x01(\x0b\x32+.SpaceX.API.Device.RadioStats.ThermalStatusR\rthermalStatus\x12R\n\x0e\x61ntenna_status\x18\x05 \x01(\x0b\x32+.SpaceX.API.Device.RadioStats.AntennaStatusR\rantennaStatus\x1a\x9b\x01\n\rThermalStatus\x12\x14\n\x05level\x18\x01 \x01(\rR\x05level\x12\x16\n\x04temp\x18\x02 \x01(\rB\x02\x18\x01R\x04temp\x12\x14\n\x05temp2\x18\x03 \x01(\x01R\x05temp2\x12\'\n\x0fpower_reduction\x18\x04 \x01(\rR\x0epowerReduction\x12\x1d\n\nduty_cycle\x18\x05 \x01(\rR\tdutyCycle\x1ag\n\rAntennaStatus\x12\x14\n\x05rssi1\x18\x01 \x01(\x02R\x05rssi1\x12\x14\n\x05rssi2\x18\x02 \x01(\x02R\x05rssi2\x12\x14\n\x05rssi3\x18\x03 \x01(\x02R\x05rssi3\x12\x14\n\x05rssi4\x18\x04 \x01(\x02R\x05rssi4\"\xf2\xa2\x01\n\"starlink_routers_hourly_metrics_v2\x12,\n\x02id\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x02id\x12\x43\n\x0etimestamp_date\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\rtimestampDate\x12\x43\n\x0etimestamp_hour\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\rtimestampHour\x12Q\n\ttimestamp\x18\x90N \x01(\x0b\x32\x32.SpaceX.API.Telemetron.Public.Common.TimestampInfoR\ttimestamp\x12:\n\nsys_hw_gen\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x08sysHwGen\x12\x33\n\x06sys_sw\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x05sysSw\x12=\n\x0bsys_country\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\nsysCountry\x12\x38\n\nsys_is_dev\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValueR\x08sysIsDev\x12@\n\rsys_alloc_fds\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x0bsysAllocFds\x12?\n\rsys_cpu_usage\x18\t \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x0bsysCpuUsage\x12\x42\n\x0fsys_mem_free_kb\x18\n \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x0csysMemFreeKb\x12@\n\rsys_bootcount\x18\x0b \x01(\x0b\x32\x1b.google.protobuf.Int32ValueR\x0csysBootcount\x12L\n\x14sys_partitions_equal\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.BoolValueR\x12sysPartitionsEqual\x12J\n\x12sys_uptime_seconds\x18\r \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x10sysUptimeSeconds\x12V\n\x19sys_anti_rollback_version\x18\x0e \x01(\x0b\x32\x1b.google.protobuf.Int32ValueR\x16sysAntiRollbackVersion\x12:\n\x0bsys_is_witl\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.BoolValueR\tsysIsWitl\x12U\n\x19sys_is_aviation_conformed\x18\x10 \x01(\x0b\x32\x1a.google.protobuf.BoolValueR\x16sysIsAviationConformed\x12\x41\n\x0esys_ubi_max_ec\x18\x11 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x0bsysUbiMaxEc\x12\x43\n\x0fsys_ubi_bad_peb\x18\x12 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x0csysUbiBadPeb\x12@\n\rsys_board_rev\x18\x13 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x0bsysBoardRev\x12L\n\x13radios_2ghz_channel\x18\x64 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x11radios2ghzChannel\x12V\n\x19radios_2ghz_antenna1_rssi\x18\x65 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x16radios2ghzAntenna1Rssi\x12V\n\x19radios_2ghz_antenna2_rssi\x18\x66 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x16radios2ghzAntenna2Rssi\x12V\n\x19radios_2ghz_antenna3_rssi\x18g \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x16radios2ghzAntenna3Rssi\x12W\n\x19radios_2ghz_antenna4_rssi\x18\xc5\x01 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x16radios2ghzAntenna4Rssi\x12W\n\x19radios_2ghz_antenna1_tssi\x18\x9d\x01 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x16radios2ghzAntenna1Tssi\x12W\n\x19radios_2ghz_antenna2_tssi\x18\x9e\x01 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x16radios2ghzAntenna2Tssi\x12W\n\x19radios_2ghz_antenna3_tssi\x18\x9f\x01 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x16radios2ghzAntenna3Tssi\x12W\n\x19radios_2ghz_antenna4_tssi\x18\xa0\x01 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x16radios2ghzAntenna4Tssi\x12S\n\x17radios_2ghz_iface_count\x18h \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x14radios2ghzIfaceCount\x12_\n\x1eradios_2ghz_chan_busy_fraction\x18i \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x1aradios2ghzChanBusyFraction\x12X\n\x1aradios_2ghz_edcca_fraction\x18j \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x17radios2ghzEdccaFraction\x12k\n$radios_2ghz_overlapping_bss_fraction\x18k \x01(\x0b\x32\x1b.google.protobuf.FloatValueR radios2ghzOverlappingBssFraction\x12L\n\x14radios_2ghz_rx_bytes\x18l \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x11radios2ghzRxBytes\x12P\n\x16radios_2ghz_rx_packets\x18m \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x13radios2ghzRxPackets\x12N\n\x15radios_2ghz_rx_errors\x18n \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x12radios2ghzRxErrors\x12Y\n\x1bradios_2ghz_rx_frame_errors\x18o \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x17radios2ghzRxFrameErrors\x12\x62\n radios_2ghz_rx_packet_error_rate\x18p \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x1bradios2ghzRxPacketErrorRate\x12\x61\n\x1fradios_2ghz_rx_airtime_fraction\x18q \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x1bradios2ghzRxAirtimeFraction\x12L\n\x14radios_2ghz_tx_bytes\x18r \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x11radios2ghzTxBytes\x12P\n\x16radios_2ghz_tx_packets\x18s \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x13radios2ghzTxPackets\x12N\n\x15radios_2ghz_tx_errors\x18t \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x12radios2ghzTxErrors\x12\x62\n radios_2ghz_tx_packet_error_rate\x18u \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x1bradios2ghzTxPacketErrorRate\x12\x61\n\x1fradios_2ghz_tx_airtime_fraction\x18v \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x1bradios2ghzTxAirtimeFraction\x12L\n\x13radios_5ghz_channel\x18w \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x11radios5ghzChannel\x12V\n\x19radios_5ghz_antenna1_rssi\x18x \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x16radios5ghzAntenna1Rssi\x12V\n\x19radios_5ghz_antenna2_rssi\x18y \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x16radios5ghzAntenna2Rssi\x12V\n\x19radios_5ghz_antenna3_rssi\x18z \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x16radios5ghzAntenna3Rssi\x12W\n\x19radios_5ghz_antenna4_rssi\x18\xc6\x01 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x16radios5ghzAntenna4Rssi\x12W\n\x19radios_5ghz_antenna1_tssi\x18\xa1\x01 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x16radios5ghzAntenna1Tssi\x12W\n\x19radios_5ghz_antenna2_tssi\x18\xa2\x01 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x16radios5ghzAntenna2Tssi\x12W\n\x19radios_5ghz_antenna3_tssi\x18\xa3\x01 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x16radios5ghzAntenna3Tssi\x12W\n\x19radios_5ghz_antenna4_tssi\x18\xa4\x01 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x16radios5ghzAntenna4Tssi\x12S\n\x17radios_5ghz_iface_count\x18{ \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x14radios5ghzIfaceCount\x12_\n\x1eradios_5ghz_chan_busy_fraction\x18| \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x1aradios5ghzChanBusyFraction\x12X\n\x1aradios_5ghz_edcca_fraction\x18} \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x17radios5ghzEdccaFraction\x12k\n$radios_5ghz_overlapping_bss_fraction\x18~ \x01(\x0b\x32\x1b.google.protobuf.FloatValueR radios5ghzOverlappingBssFraction\x12L\n\x14radios_5ghz_rx_bytes\x18\x7f \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x11radios5ghzRxBytes\x12Q\n\x16radios_5ghz_rx_packets\x18\x80\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x13radios5ghzRxPackets\x12O\n\x15radios_5ghz_rx_errors\x18\x81\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x12radios5ghzRxErrors\x12Z\n\x1bradios_5ghz_rx_frame_errors\x18\x82\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x17radios5ghzRxFrameErrors\x12\x63\n radios_5ghz_rx_packet_error_rate\x18\x83\x01 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x1bradios5ghzRxPacketErrorRate\x12\x62\n\x1fradios_5ghz_rx_airtime_fraction\x18\x84\x01 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x1bradios5ghzRxAirtimeFraction\x12M\n\x14radios_5ghz_tx_bytes\x18\x85\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x11radios5ghzTxBytes\x12Q\n\x16radios_5ghz_tx_packets\x18\x86\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x13radios5ghzTxPackets\x12O\n\x15radios_5ghz_tx_errors\x18\x87\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x12radios5ghzTxErrors\x12\x63\n radios_5ghz_tx_packet_error_rate\x18\x88\x01 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x1bradios5ghzTxPacketErrorRate\x12\x62\n\x1fradios_5ghz_tx_airtime_fraction\x18\x89\x01 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x1bradios5ghzTxAirtimeFraction\x12V\n\x18radios_5ghz_high_channel\x18\x8a\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x15radios5ghzHighChannel\x12`\n\x1eradios_5ghz_high_antenna1_rssi\x18\x8b\x01 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x1aradios5ghzHighAntenna1Rssi\x12`\n\x1eradios_5ghz_high_antenna2_rssi\x18\x8c\x01 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x1aradios5ghzHighAntenna2Rssi\x12`\n\x1eradios_5ghz_high_antenna3_rssi\x18\x8d\x01 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x1aradios5ghzHighAntenna3Rssi\x12`\n\x1eradios_5ghz_high_antenna4_rssi\x18\xc7\x01 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x1aradios5ghzHighAntenna4Rssi\x12`\n\x1eradios_5ghz_high_antenna1_tssi\x18\xa5\x01 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x1aradios5ghzHighAntenna1Tssi\x12`\n\x1eradios_5ghz_high_antenna2_tssi\x18\xa6\x01 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x1aradios5ghzHighAntenna2Tssi\x12`\n\x1eradios_5ghz_high_antenna3_tssi\x18\xa7\x01 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x1aradios5ghzHighAntenna3Tssi\x12`\n\x1eradios_5ghz_high_antenna4_tssi\x18\xa8\x01 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x1aradios5ghzHighAntenna4Tssi\x12]\n\x1cradios_5ghz_high_iface_count\x18\x8e\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x18radios5ghzHighIfaceCount\x12i\n#radios_5ghz_high_chan_busy_fraction\x18\x8f\x01 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x1eradios5ghzHighChanBusyFraction\x12\x62\n\x1fradios_5ghz_high_edcca_fraction\x18\x90\x01 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x1bradios5ghzHighEdccaFraction\x12u\n)radios_5ghz_high_overlapping_bss_fraction\x18\x91\x01 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR$radios5ghzHighOverlappingBssFraction\x12V\n\x19radios_5ghz_high_rx_bytes\x18\x92\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x15radios5ghzHighRxBytes\x12Z\n\x1bradios_5ghz_high_rx_packets\x18\x93\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x17radios5ghzHighRxPackets\x12X\n\x1aradios_5ghz_high_rx_errors\x18\x94\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x16radios5ghzHighRxErrors\x12\x63\n radios_5ghz_high_rx_frame_errors\x18\x95\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x1bradios5ghzHighRxFrameErrors\x12l\n%radios_5ghz_high_rx_packet_error_rate\x18\x96\x01 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x1fradios5ghzHighRxPacketErrorRate\x12k\n$radios_5ghz_high_rx_airtime_fraction\x18\x97\x01 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x1fradios5ghzHighRxAirtimeFraction\x12V\n\x19radios_5ghz_high_tx_bytes\x18\x98\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x15radios5ghzHighTxBytes\x12Z\n\x1bradios_5ghz_high_tx_packets\x18\x99\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x17radios5ghzHighTxPackets\x12X\n\x1aradios_5ghz_high_tx_errors\x18\x9a\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x16radios5ghzHighTxErrors\x12l\n%radios_5ghz_high_tx_packet_error_rate\x18\x9b\x01 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x1fradios5ghzHighTxPacketErrorRate\x12k\n$radios_5ghz_high_tx_airtime_fraction\x18\x9c\x01 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x1fradios5ghzHighTxAirtimeFraction\x12U\n\x18radios_2ghz_thermal_temp\x18\xc8\x01 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x15radios2ghzThermalTemp\x12U\n\x18radios_5ghz_thermal_temp\x18\xc9\x01 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x15radios5ghzThermalTemp\x12^\n\x1dradios_5ghz_high_thermal_temp\x18\xce\x01 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x19radios5ghzHighThermalTemp\x12`\n\x1eradios_2ghz_thermal_duty_cycle\x18\xca\x01 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x1aradios2ghzThermalDutyCycle\x12`\n\x1eradios_5ghz_thermal_duty_cycle\x18\xcb\x01 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x1aradios5ghzThermalDutyCycle\x12i\n#radios_5ghz_high_thermal_duty_cycle\x18\xcf\x01 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x1eradios5ghzHighThermalDutyCycle\x12o\n%radios_2ghz_thermal_throttled_seconds\x18\xcc\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR!radios2ghzThermalThrottledSeconds\x12o\n%radios_5ghz_thermal_throttled_seconds\x18\xcd\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR!radios5ghzThermalThrottledSeconds\x12x\n*radios_5ghz_high_thermal_throttled_seconds\x18\xd0\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR%radios5ghzHighThermalThrottledSeconds\x12;\n\nboard_temp\x18\xd2\x01 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\tboardTemp\x12\x45\n\x10poe_mcu_die_temp\x18\xd3\x01 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\rpoeMcuDieTemp\x12R\n\x17ifaces_lan_eth_rx_bytes\x18\xac\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x13ifacesLanEthRxBytes\x12V\n\x19ifaces_lan_eth_rx_packets\x18\xad\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x15ifacesLanEthRxPackets\x12T\n\x18ifaces_lan_eth_rx_errors\x18\xae\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x14ifacesLanEthRxErrors\x12_\n\x1eifaces_lan_eth_rx_frame_errors\x18\xaf\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x19ifacesLanEthRxFrameErrors\x12R\n\x17ifaces_lan_eth_tx_bytes\x18\xb0\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x13ifacesLanEthTxBytes\x12V\n\x19ifaces_lan_eth_tx_packets\x18\xb1\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x15ifacesLanEthTxPackets\x12T\n\x18ifaces_lan_eth_tx_errors\x18\xb2\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x14ifacesLanEthTxErrors\x12T\n\x18ifaces_lan1_eth_rx_bytes\x18\xba\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x14ifacesLan1EthRxBytes\x12X\n\x1aifaces_lan1_eth_rx_packets\x18\xbb\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x16ifacesLan1EthRxPackets\x12V\n\x19ifaces_lan1_eth_rx_errors\x18\xbc\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x15ifacesLan1EthRxErrors\x12\x61\n\x1fifaces_lan1_eth_rx_frame_errors\x18\xbd\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x1aifacesLan1EthRxFrameErrors\x12T\n\x18ifaces_lan1_eth_tx_bytes\x18\xbe\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x14ifacesLan1EthTxBytes\x12X\n\x1aifaces_lan1_eth_tx_packets\x18\xbf\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x16ifacesLan1EthTxPackets\x12V\n\x19ifaces_lan1_eth_tx_errors\x18\xc0\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x15ifacesLan1EthTxErrors\x12R\n\x17ifaces_wan_eth_rx_bytes\x18\xb3\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x13ifacesWanEthRxBytes\x12V\n\x19ifaces_wan_eth_rx_packets\x18\xb4\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x15ifacesWanEthRxPackets\x12T\n\x18ifaces_wan_eth_rx_errors\x18\xb5\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x14ifacesWanEthRxErrors\x12_\n\x1eifaces_wan_eth_rx_frame_errors\x18\xb6\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x19ifacesWanEthRxFrameErrors\x12R\n\x17ifaces_wan_eth_tx_bytes\x18\xb7\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x13ifacesWanEthTxBytes\x12V\n\x19ifaces_wan_eth_tx_packets\x18\xb8\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x15ifacesWanEthTxPackets\x12T\n\x18ifaces_wan_eth_tx_errors\x18\xb9\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x14ifacesWanEthTxErrors\x12\x37\n\x07\x63lients\x18\x90\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x07\x63lients\x12@\n\x0c\x63lients_2ghz\x18\x91\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x0b\x63lients2ghz\x12@\n\x0c\x63lients_5ghz\x18\x92\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x0b\x63lients5ghz\x12I\n\x11\x63lients_5ghz_high\x18\x9d\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x0f\x63lients5ghzHigh\x12>\n\x0b\x63lients_eth\x18\x93\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\nclientsEth\x12\x63\n\x1f\x63lients_5ghz_rx_bandwidth_20mhz\x18\xad\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x1b\x63lients5ghzRxBandwidth20mhz\x12\x63\n\x1f\x63lients_5ghz_rx_bandwidth_40mhz\x18\xae\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x1b\x63lients5ghzRxBandwidth40mhz\x12\x63\n\x1f\x63lients_5ghz_rx_bandwidth_80mhz\x18\xaf\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x1b\x63lients5ghzRxBandwidth80mhz\x12H\n\x10\x63lients_repeater\x18\x94\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x0f\x63lientsRepeater\x12Q\n\x15\x63lients_repeater_2ghz\x18\x95\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x13\x63lientsRepeater2ghz\x12Q\n\x15\x63lients_repeater_5ghz\x18\x96\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x13\x63lientsRepeater5ghz\x12Z\n\x1a\x63lients_repeater_5ghz_high\x18\xa0\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x17\x63lientsRepeater5ghzHigh\x12O\n\x14\x63lients_repeater_eth\x18\x97\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x12\x63lientsRepeaterEth\x12:\n\tmesh_hops\x18\x98\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x08meshHops\x12W\n\x1amesh_one_hop_rssi_avg_2ghz\x18\x99\x03 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x15meshOneHopRssiAvg2ghz\x12W\n\x1amesh_one_hop_rssi_avg_5ghz\x18\x9a\x03 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x15meshOneHopRssiAvg5ghz\x12`\n\x1fmesh_one_hop_rssi_avg_5ghz_high\x18\x9e\x03 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x19meshOneHopRssiAvg5ghzHigh\x12W\n\x1amesh_two_hop_rssi_avg_2ghz\x18\x9b\x03 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x15meshTwoHopRssiAvg2ghz\x12W\n\x1amesh_two_hop_rssi_avg_5ghz\x18\x9c\x03 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x15meshTwoHopRssiAvg5ghz\x12`\n\x1fmesh_two_hop_rssi_avg_5ghz_high\x18\x9f\x03 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x19meshTwoHopRssiAvg5ghzHigh\x12V\n\x19repeater_tx_rate_mbps_min\x18\xa2\x03 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x15repeaterTxRateMbpsMin\x12V\n\x19repeater_rx_rate_mbps_min\x18\xa3\x03 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x15repeaterRxRateMbpsMin\x12V\n\x19repeater_tx_rate_mbps_avg\x18\xa4\x03 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x15repeaterTxRateMbpsAvg\x12V\n\x19repeater_rx_rate_mbps_avg\x18\xa5\x03 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x15repeaterRxRateMbpsAvg\x12k\n$repeater_seconds_since_2s_outage_min\x18\xa6\x03 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x1frepeaterSecondsSince2sOutageMin\x12k\n$repeater_seconds_since_5s_outage_min\x18\xa8\x03 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x1frepeaterSecondsSince5sOutageMin\x12k\n$repeater_seconds_since_2s_outage_avg\x18\xa7\x03 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x1frepeaterSecondsSince2sOutageAvg\x12k\n$repeater_seconds_since_5s_outage_avg\x18\xa9\x03 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x1frepeaterSecondsSince5sOutageAvg\x12X\n\x1arepeater_latency_ms_1h_max\x18\xaa\x03 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x16repeaterLatencyMs1hMax\x12X\n\x1arepeater_latency_ms_1h_avg\x18\xab\x03 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x16repeaterLatencyMs1hAvg\x12_\n\x1dmesh_topology_change_count_1d\x18\xac\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x19meshTopologyChangeCount1d\x12\x65\n!ping_seconds_since_last_1s_outage\x18\xd8\x04 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x1cpingSecondsSinceLast1sOutage\x12\x65\n!ping_seconds_since_last_2s_outage\x18\xd9\x04 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x1cpingSecondsSinceLast2sOutage\x12\x65\n!ping_seconds_since_last_5s_outage\x18\xda\x04 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x1cpingSecondsSinceLast5sOutage\x12g\n\"ping_seconds_since_last_60s_outage\x18\xdb\x04 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x1dpingSecondsSinceLast60sOutage\x12i\n#ping_seconds_since_last_300s_outage\x18\xdc\x04 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x1epingSecondsSinceLast300sOutage\x12\x42\n\x0eping_drop_rate\x18\xdd\x04 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x0cpingDropRate\x12P\n\x16ping_drop_rate_last_1h\x18\xde\x04 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x12pingDropRateLast1h\x12?\n\x0cping_latency\x18\xdf\x04 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x0bpingLatency\x12M\n\x14ping_latency_last_1h\x18\xea\x04 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x11pingLatencyLast1h\x12n\n&ping_dish_seconds_since_last_1s_outage\x18\xe2\x04 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR pingDishSecondsSinceLast1sOutage\x12n\n&ping_dish_seconds_since_last_2s_outage\x18\xe3\x04 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR pingDishSecondsSinceLast2sOutage\x12n\n&ping_dish_seconds_since_last_5s_outage\x18\xe4\x04 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR pingDishSecondsSinceLast5sOutage\x12p\n\'ping_dish_seconds_since_last_60s_outage\x18\xe5\x04 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR!pingDishSecondsSinceLast60sOutage\x12r\n(ping_dish_seconds_since_last_300s_outage\x18\xe6\x04 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\"pingDishSecondsSinceLast300sOutage\x12K\n\x13ping_dish_drop_rate\x18\xe7\x04 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x10pingDishDropRate\x12Y\n\x1bping_dish_drop_rate_last_1h\x18\xe8\x04 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x16pingDishDropRateLast1h\x12H\n\x11ping_dish_latency\x18\xe9\x04 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x0fpingDishLatency\x12V\n\x19ping_dish_latency_last_1h\x18\xeb\x04 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x15pingDishLatencyLast1h\x12n\n%client_speedtest_router_download_mbps\x18\xbc\x05 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR!clientSpeedtestRouterDownloadMbps\x12j\n#client_speedtest_router_upload_mbps\x18\xbd\x05 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x1f\x63lientSpeedtestRouterUploadMbps\x12]\n\x1c\x63lient_speedtest_router_rssi\x18\xbe\x05 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x19\x63lientSpeedtestRouterRssi\x12j\n#client_speedtest_wifi_download_mbps\x18\xbf\x05 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x1f\x63lientSpeedtestWifiDownloadMbps\x12\x66\n!client_speedtest_wifi_upload_mbps\x18\xc0\x05 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x1d\x63lientSpeedtestWifiUploadMbps\x12n\n%client_speedtest_client_download_mbps\x18\xc1\x05 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR!clientSpeedtestClientDownloadMbps\x12j\n#client_speedtest_client_upload_mbps\x18\xc2\x05 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x1f\x63lientSpeedtestClientUploadMbps\x12]\n\x1c\x63lient_speedtest_client_rssi\x18\xc3\x05 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x19\x63lientSpeedtestClientRssi\x12`\n\x1d\x63lient_speedtest_client_iface\x18\xc4\x05 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x1a\x63lientSpeedtestClientIface\x12\\\n\x1b\x63lient_speedtest_client_oui\x18\xc5\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x18\x63lientSpeedtestClientOui\x12\x63\n\x1f\x63lient_speedtest_client_tx_rate\x18\xc6\x05 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x1b\x63lientSpeedtestClientTxRate\x12\x63\n\x1f\x63lient_speedtest_client_rx_rate\x18\xc7\x05 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x1b\x63lientSpeedtestClientRxRate\x12o\n%client_speedtest_client_platform_type\x18\xc8\x05 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR!clientSpeedtestClientPlatformType\x12\x65\n!speedtest_tcp_8_download_mbps_avg\x18\xa0\x06 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x1cspeedtestTcp8DownloadMbpsAvg\x12\x65\n!speedtest_tcp_8_download_mbps_max\x18\xa1\x06 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x1cspeedtestTcp8DownloadMbpsMax\x12\x61\n\x1fspeedtest_tcp_8_upload_mbps_avg\x18\xa2\x06 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x1aspeedtestTcp8UploadMbpsAvg\x12\x61\n\x1fspeedtest_tcp_8_upload_mbps_max\x18\xa3\x06 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x1aspeedtestTcp8UploadMbpsMax\x12g\n\"speedtest_tcp_64_download_mbps_avg\x18\xa4\x06 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x1dspeedtestTcp64DownloadMbpsAvg\x12g\n\"speedtest_tcp_64_download_mbps_max\x18\xa5\x06 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x1dspeedtestTcp64DownloadMbpsMax\x12\x63\n speedtest_tcp_64_upload_mbps_avg\x18\xa6\x06 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x1bspeedtestTcp64UploadMbpsAvg\x12\x63\n speedtest_tcp_64_upload_mbps_max\x18\xa7\x06 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x1bspeedtestTcp64UploadMbpsMax\x12?\n\x0c\x64ish_cell_id\x18\x84\x07 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\ndishCellId\x12O\n\x15\x63onfig_setup_complete\x18\xe8\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValueR\x13\x63onfigSetupComplete\x12I\n\x12\x63onfig_bands_split\x18\xe9\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValueR\x10\x63onfigBandsSplit\x12I\n\x12\x63onfig_is_repeater\x18\xea\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValueR\x10\x63onfigIsRepeater\x12K\n\x13\x63onfig_open_network\x18\xeb\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValueR\x11\x63onfigOpenNetwork\x12I\n\x12\x63onfig_is_aviation\x18\xec\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValueR\x10\x63onfigIsAviation\x12G\n\x11\x63onfig_secure_dns\x18\xed\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValueR\x0f\x63onfigSecureDns\x12@\n\rconfig_legacy\x18\xee\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValueR\x0c\x63onfigLegacy\x12\x41\n\x0e\x63onfig_ap_mode\x18\xef\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValueR\x0c\x63onfigApMode\x12I\n\x12\x63onfig_dfs_enabled\x18\xf0\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValueR\x10\x63onfigDfsEnabled\x12_\n\x1e\x63onfig_network_name_is_default\x18\xf1\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValueR\x1a\x63onfigNetworkNameIsDefault\x12V\n\x19\x63onfig_remote_ssh_enabled\x18\xf2\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValueR\x16\x63onfigRemoteSshEnabled\x12T\n\x18\x63onfig_is_repeater_wired\x18\xf3\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValueR\x15\x63onfigIsRepeaterWired\x12Z\n\x1b\x63onfig_is_repeater_wireless\x18\xf4\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValueR\x18\x63onfigIsRepeaterWireless\x12Z\n\x1a\x63onfig_block_schedules_set\x18\xf5\x07 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x17\x63onfigBlockSchedulesSet\x12W\n\x19\x63onfig_custom_nameservers\x18\xf6\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValueR\x17\x63onfigCustomNameservers\x12`\n\x1e\x63onfig_disable_mesh_onboarding\x18\xf7\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValueR\x1b\x63onfigDisableMeshOnboarding\x12R\n\x17\x63onfig_pin_country_code\x18\xf8\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValueR\x14\x63onfigPinCountryCode\x12\\\n\x1c\x63onfig_disable_update_reboot\x18\xf9\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValueR\x19\x63onfigDisableUpdateReboot\x12K\n\x13\x63onfig_disable_2ghz\x18\xfa\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValueR\x11\x63onfigDisable2ghz\x12K\n\x13\x63onfig_disable_5ghz\x18\xfb\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValueR\x11\x63onfigDisable5ghz\x12T\n\x18\x63onfig_disable_5ghz_high\x18\x85\x08 \x01(\x0b\x32\x1a.google.protobuf.BoolValueR\x15\x63onfigDisable5ghzHigh\x12M\n\x13\x63onfig_channel_2ghz\x18\xfc\x07 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x11\x63onfigChannel2ghz\x12M\n\x13\x63onfig_channel_5ghz\x18\xfd\x07 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x11\x63onfigChannel5ghz\x12V\n\x18\x63onfig_channel_5ghz_high\x18\xfe\x07 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x15\x63onfigChannel5ghzHigh\x12\x46\n\x0f\x63onfig_networks\x18\xff\x07 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x0e\x63onfigNetworks\x12Q\n\x15\x63onfig_networks_guest\x18\x80\x08 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x13\x63onfigNetworksGuest\x12S\n\x16\x63onfig_networks_hidden\x18\x81\x08 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x14\x63onfigNetworksHidden\x12\x66\n config_networks_client_isolation\x18\x82\x08 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x1d\x63onfigNetworksClientIsolation\x12\\\n\x1b\x63onfig_networks_bands_split\x18\x83\x08 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x18\x63onfigNetworksBandsSplit\x12`\n\x1ewan_traffic_control_cake_bytes\x18\xcd\x08 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x1awanTrafficControlCakeBytes\x12\x64\n wan_traffic_control_cake_packets\x18\xce\x08 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x1cwanTrafficControlCakePackets\x12`\n\x1ewan_traffic_control_cake_drops\x18\xcf\x08 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x1awanTrafficControlCakeDrops\x12g\n\"wan_traffic_control_cake_ack_drops\x18\xd0\x08 \x01(\x0b\x32\x1b.google.protobuf.Int64ValueR\x1dwanTrafficControlCakeAckDrops\x12J\n\x11\x63onntrack_entries\x18\xcc\x08 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x10\x63onntrackEntries\x12\x42\n\x0e\x64hcp_secs_eq_0\x18\xd1\x08 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x0b\x64hcpSecsEq0\x12\x42\n\x0e\x64hcp_secs_gt_0\x18\xd2\x08 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x0b\x64hcpSecsGt0\x12\x44\n\x0f\x64hcp_secs_gt_10\x18\xd3\x08 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x0c\x64hcpSecsGt10\x12\x44\n\x0f\x64hcp_secs_gt_30\x18\xd4\x08 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x0c\x64hcpSecsGt30\x12\x44\n\x0f\x64hcp_secs_gt_60\x18\xd5\x08 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x0c\x64hcpSecsGt60\"\xec\x01\n\x16starlink_router_alerts\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12\x16\n\x06source\x18\x02 \x01(\tR\x06source\x12\x16\n\x06\x61\x63tive\x18\x03 \x01(\x08R\x06\x61\x63tive\x12H\n\x05start\x18\x04 \x01(\x0b\x32\x32.SpaceX.API.Telemetron.Public.Common.TimestampInfoR\x05start\x12\x44\n\x03\x65nd\x18\x05 \x01(\x0b\x32\x32.SpaceX.API.Telemetron.Public.Common.TimestampInfoR\x03\x65nd\"\xe1\x13\n!starlink_router_client_speedtests\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12S\n\x0b\x64\x61ta_record\x18\x02 \x01(\x0b\x32\x32.SpaceX.API.Telemetron.Public.Common.TimestampInfoR\ndataRecord\x12\x18\n\x07\x63ountry\x18\x03 \x01(\tR\x07\x63ountry\x12?\n\x0cspeedtest_id\x18\x1e \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x0bspeedtestId\x12<\n\x0b\x63lient_rssi\x18\x08 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\nclientRssi\x12<\n\x0brouter_rssi\x18\t \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\nrouterRssi\x12?\n\x0c\x63lient_iface\x18\n \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x0b\x63lientIface\x12;\n\nclient_oui\x18\x0b \x01(\x0b\x32\x1c.google.protobuf.StringValueR\tclientOui\x12\x42\n\x0e\x63lient_tx_rate\x18\x0c \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x0c\x63lientTxRate\x12\x42\n\x0e\x63lient_rx_rate\x18\r \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x0c\x63lientRxRate\x12N\n\x14\x63lient_platform_type\x18\x1b \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x12\x63lientPlatformType\x12J\n\x12\x63lient_app_version\x18\" \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x10\x63lientAppVersion\x12\x46\n\x10\x63lient_app_build\x18# \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x0e\x63lientAppBuild\x12I\n\x12\x63lient_rx_phy_mode\x18\x1f \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x0f\x63lientRxPhyMode\x12W\n\x19\x63lient_rx_spatial_streams\x18  \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x16\x63lientRxSpatialStreams\x12@\n\rclient_rx_mcs\x18! \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x0b\x63lientRxMcs\x12o\n\x1a\x63lient_download_start_time\x18\x04 \x01(\x0b\x32\x32.SpaceX.API.Telemetron.Public.Common.TimestampInfoR\x17\x63lientDownloadStartTime\x12k\n\x18\x63lient_upload_start_time\x18\x05 \x01(\x0b\x32\x32.SpaceX.API.Telemetron.Public.Common.TimestampInfoR\x15\x63lientUploadStartTime\x12T\n\x18\x63lient_download_mbps_avg\x18\x06 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x15\x63lientDownloadMbpsAvg\x12P\n\x16\x63lient_upload_mbps_avg\x18\x07 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x13\x63lientUploadMbpsAvg\x12\x41\n\rclient_target\x18\x1c \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x0c\x63lientTarget\x12J\n\x12\x63lient_tcp_streams\x18\x10 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x10\x63lientTcpStreams\x12o\n\x1arouter_download_start_time\x18\x11 \x01(\x0b\x32\x32.SpaceX.API.Telemetron.Public.Common.TimestampInfoR\x17routerDownloadStartTime\x12k\n\x18router_upload_start_time\x18\x12 \x01(\x0b\x32\x32.SpaceX.API.Telemetron.Public.Common.TimestampInfoR\x15routerUploadStartTime\x12T\n\x18router_download_mbps_avg\x18\x13 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x15routerDownloadMbpsAvg\x12P\n\x16router_upload_mbps_avg\x18\x14 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x13routerUploadMbpsAvg\x12\x41\n\rrouter_target\x18\x1d \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x0crouterTarget\x12J\n\x12router_tcp_streams\x18\x16 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x10routerTcpStreams\x12k\n\x18wifi_download_start_time\x18\x17 \x01(\x0b\x32\x32.SpaceX.API.Telemetron.Public.Common.TimestampInfoR\x15wifiDownloadStartTime\x12g\n\x16wifi_upload_start_time\x18\x18 \x01(\x0b\x32\x32.SpaceX.API.Telemetron.Public.Common.TimestampInfoR\x13wifiUploadStartTime\x12P\n\x16wifi_download_mbps_avg\x18\x19 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x13wifiDownloadMbpsAvg\x12L\n\x14wifi_upload_mbps_avg\x18\x1a \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x11wifiUploadMbpsAvgJ\x04\x08\x0e\x10\x0fJ\x04\x08\x0f\x10\x10J\x04\x08\x15\x10\x16\"\xb7\x10\n\x15StarlinkRouterClients\x12\x1b\n\trouter_id\x18\x01 \x01(\tR\x08routerId\x12P\n\ttimestamp\x18\x02 \x01(\x0b\x32\x32.SpaceX.API.Telemetron.Public.Common.TimestampInfoR\ttimestamp\x12\x1b\n\tclient_id\x18\x03 \x01(\rR\x08\x63lientId\x12,\n\x12\x63lient_telem_index\x18\x04 \x01(\tR\x10\x63lientTelemIndex\x12\x39\n\trouter_hw\x18w \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x08routerHw\x12\x39\n\trouter_sw\x18x \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x08routerSw\x12\x46\n\x10\x63lient_router_id\x18y \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x0e\x63lientRouterId\x12\x39\n\tclient_hw\x18z \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x08\x63lientHw\x12\x39\n\tclient_sw\x18{ \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x08\x63lientSw\x12.\n\x03oui\x18\x65 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x03oui\x12=\n\x0bupstream_id\x18\x66 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\nupstreamId\x12;\n\x0bis_repeater\x18g \x01(\x0b\x32\x1a.google.protobuf.BoolValueR\nisRepeater\x12=\n\x0b\x63onnected_s\x18h \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\nconnectedS\x12:\n\tinterface\x18i \x01(\x0b\x32\x1c.google.protobuf.StringValueR\tinterface\x12\x41\n\rradio_channel\x18j \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x0cradioChannel\x12/\n\x04rssi\x18k \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x04rssi\x12\x33\n\x06rx_mcs\x18l \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x05rxMcs\x12\x33\n\x06tx_mcs\x18m \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x05txMcs\x12\x35\n\x07rx_rate\x18n \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x06rxRate\x12\x35\n\x07tx_rate\x18o \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x06txRate\x12?\n\x0crx_bandwidth\x18p \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x0brxBandwidth\x12J\n\x12rx_spatial_streams\x18q \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x10rxSpatialStreams\x12<\n\x0brx_phy_mode\x18r \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\trxPhyMode\x12\x39\n\tmesh_hops\x18v \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x08meshHops\x12O\n\x15speedtest_upload_mbps\x18| \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x13speedtestUploadMbps\x12S\n\x17speedtest_download_mbps\x18} \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x15speedtestDownloadMbps\x12\x45\n\x10site_survey_rssi\x18\x7f \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x0esiteSurveyRssi\x12R\n\x17site_survey_est_rx_rate\x18\x80\x01 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x13siteSurveyEstRxRate\x12\x62\n\x1e\x65st_controller_throughput_mbps\x18\x81\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x1b\x65stControllerThroughputMbps\x12O\n\x16ping_drop_rate_last_1h\x18s \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x12pingDropRateLast1h\x12L\n\x14ping_latency_last_1h\x18t \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x11pingLatencyLast1h\x12=\n\x0bsteer_state\x18u \x01(\x0b\x32\x1c.google.protobuf.StringValueR\nsteerState\x12\x34\n\x07\x62locked\x18~ \x01(\x0b\x32\x1a.google.protobuf.BoolValueR\x07\x62locked\"\xa9\x01\n\x1dWifiSetClientGivenNameRequest\x12\x42\n\x0b\x63lient_name\x18\x01 \x01(\x0b\x32\x1d.SpaceX.API.Device.ClientNameB\x02\x18\x01R\nclientName\x12\x44\n\rclient_config\x18\x02 \x01(\x0b\x32\x1f.SpaceX.API.Device.ClientConfigR\x0c\x63lientConfig\"\x15\n\x13WifiSelfTestRequest\"h\n\x14WifiSelfTestResponse\x12<\n\tself_test\x18\x01 \x01(\x0b\x32\x1f.SpaceX.API.Device.WifiSelfTestR\x08selfTest\x12\x12\n\x04json\x18\x02 \x01(\tR\x04json\"\x18\n\x16WifiRunSelfTestRequest\"\xff\x02\n\x11WifiRfTestRequest\x12)\n\x10num_measurements\x18\x01 \x01(\rR\x0fnumMeasurements\x12!\n\x0c\x63hannel_2ghz\x18\x02 \x01(\rR\x0b\x63hannel2ghz\x12!\n\x0c\x63hannel_5ghz\x18\x03 \x01(\rR\x0b\x63hannel5ghz\x12*\n\x11\x63hannel_5ghz_high\x18\x04 \x01(\rR\x0f\x63hannel5ghzHigh\x12\x19\n\x08mcs_2ghz\x18\x05 \x01(\rR\x07mcs2ghz\x12\x19\n\x08mcs_5ghz\x18\x06 \x01(\rR\x07mcs5ghz\x12\"\n\rmcs_5ghz_high\x18\x07 \x01(\rR\x0bmcs5ghzHigh\x12\"\n\rphy_mode_2ghz\x18\x08 \x01(\rR\x0bphyMode2ghz\x12\"\n\rphy_mode_5ghz\x18\t \x01(\rR\x0bphyMode5ghz\x12+\n\x12phy_mode_5ghz_high\x18\n \x01(\rR\x0fphyMode5ghzHigh\",\n\x12WifiRfTestResponse\x12\x16\n\x06report\x18\x01 \x01(\tR\x06report\"\x18\n\x16WifiGetFirewallRequest\"T\n\x17WifiGetFirewallResponse\x12\x1a\n\x08iptables\x18\x01 \x01(\tR\x08iptables\x12\x1d\n\niptables_6\x18\x02 \x01(\tR\tiptables6\"9\n\x1fWifiTogglePoeNegotiationRequest\x12\x16\n\x06\x65nable\x18\x01 \x01(\x08R\x06\x65nable\"\x1c\n\x1aWifiCalibrationModeRequest\"\xad\\\n!starlink_router_hourly_metrics_v2\x12,\n\x02id\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x02id\x12\x43\n\x0etimestamp_date\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\rtimestampDate\x12\x43\n\x0etimestamp_hour\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\rtimestampHour\x12:\n\nsys_hw_gen\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x08sysHwGen\x12\x33\n\x06sys_sw\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x05sysSw\x12=\n\x0bsys_country\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\nsysCountry\x12\x38\n\nsys_is_dev\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValueR\x08sysIsDev\x12@\n\rsys_alloc_fds\x18\x08 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x0bsysAllocFds\x12?\n\rsys_cpu_usage\x18\t \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x0bsysCpuUsage\x12\x42\n\x0fsys_mem_free_kb\x18\n \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x0csysMemFreeKb\x12@\n\rsys_bootcount\x18\x0b \x01(\x0b\x32\x1b.google.protobuf.Int32ValueR\x0csysBootcount\x12L\n\x14sys_partitions_equal\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.BoolValueR\x12sysPartitionsEqual\x12J\n\x12sys_uptime_seconds\x18\r \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x10sysUptimeSeconds\x12V\n\x19sys_anti_rollback_version\x18\x0e \x01(\x0b\x32\x1b.google.protobuf.Int32ValueR\x16sysAntiRollbackVersion\x12L\n\x13radios_2ghz_channel\x18\x64 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x11radios2ghzChannel\x12V\n\x19radios_2ghz_antenna1_rssi\x18\x65 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x16radios2ghzAntenna1Rssi\x12V\n\x19radios_2ghz_antenna2_rssi\x18\x66 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x16radios2ghzAntenna2Rssi\x12V\n\x19radios_2ghz_antenna3_rssi\x18g \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x16radios2ghzAntenna3Rssi\x12S\n\x17radios_2ghz_iface_count\x18h \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x14radios2ghzIfaceCount\x12_\n\x1eradios_2ghz_chan_busy_fraction\x18i \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x1aradios2ghzChanBusyFraction\x12X\n\x1aradios_2ghz_edcca_fraction\x18j \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x17radios2ghzEdccaFraction\x12k\n$radios_2ghz_overlapping_bss_fraction\x18k \x01(\x0b\x32\x1b.google.protobuf.FloatValueR radios2ghzOverlappingBssFraction\x12M\n\x14radios_2ghz_rx_bytes\x18l \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x11radios2ghzRxBytes\x12Q\n\x16radios_2ghz_rx_packets\x18m \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x13radios2ghzRxPackets\x12O\n\x15radios_2ghz_rx_errors\x18n \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x12radios2ghzRxErrors\x12Z\n\x1bradios_2ghz_rx_frame_errors\x18o \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x17radios2ghzRxFrameErrors\x12\x62\n radios_2ghz_rx_packet_error_rate\x18p \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x1bradios2ghzRxPacketErrorRate\x12\x61\n\x1fradios_2ghz_rx_airtime_fraction\x18q \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x1bradios2ghzRxAirtimeFraction\x12M\n\x14radios_2ghz_tx_bytes\x18r \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x11radios2ghzTxBytes\x12Q\n\x16radios_2ghz_tx_packets\x18s \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x13radios2ghzTxPackets\x12O\n\x15radios_2ghz_tx_errors\x18t \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x12radios2ghzTxErrors\x12\x62\n radios_2ghz_tx_packet_error_rate\x18u \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x1bradios2ghzTxPacketErrorRate\x12\x61\n\x1fradios_2ghz_tx_airtime_fraction\x18v \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x1bradios2ghzTxAirtimeFraction\x12L\n\x13radios_5ghz_channel\x18w \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x11radios5ghzChannel\x12V\n\x19radios_5ghz_antenna1_rssi\x18x \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x16radios5ghzAntenna1Rssi\x12V\n\x19radios_5ghz_antenna2_rssi\x18y \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x16radios5ghzAntenna2Rssi\x12V\n\x19radios_5ghz_antenna3_rssi\x18z \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x16radios5ghzAntenna3Rssi\x12S\n\x17radios_5ghz_iface_count\x18{ \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x14radios5ghzIfaceCount\x12_\n\x1eradios_5ghz_chan_busy_fraction\x18| \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x1aradios5ghzChanBusyFraction\x12X\n\x1aradios_5ghz_edcca_fraction\x18} \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x17radios5ghzEdccaFraction\x12k\n$radios_5ghz_overlapping_bss_fraction\x18~ \x01(\x0b\x32\x1b.google.protobuf.FloatValueR radios5ghzOverlappingBssFraction\x12M\n\x14radios_5ghz_rx_bytes\x18\x7f \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x11radios5ghzRxBytes\x12R\n\x16radios_5ghz_rx_packets\x18\x80\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x13radios5ghzRxPackets\x12P\n\x15radios_5ghz_rx_errors\x18\x81\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x12radios5ghzRxErrors\x12[\n\x1bradios_5ghz_rx_frame_errors\x18\x82\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x17radios5ghzRxFrameErrors\x12\x63\n radios_5ghz_rx_packet_error_rate\x18\x83\x01 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x1bradios5ghzRxPacketErrorRate\x12\x62\n\x1fradios_5ghz_rx_airtime_fraction\x18\x84\x01 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x1bradios5ghzRxAirtimeFraction\x12N\n\x14radios_5ghz_tx_bytes\x18\x85\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x11radios5ghzTxBytes\x12R\n\x16radios_5ghz_tx_packets\x18\x86\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x13radios5ghzTxPackets\x12P\n\x15radios_5ghz_tx_errors\x18\x87\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x12radios5ghzTxErrors\x12\x63\n radios_5ghz_tx_packet_error_rate\x18\x88\x01 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x1bradios5ghzTxPacketErrorRate\x12\x62\n\x1fradios_5ghz_tx_airtime_fraction\x18\x89\x01 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x1bradios5ghzTxAirtimeFraction\x12U\n\x18radios_2ghz_thermal_temp\x18\xc8\x01 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x15radios2ghzThermalTemp\x12U\n\x18radios_5ghz_thermal_temp\x18\xc9\x01 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x15radios5ghzThermalTemp\x12`\n\x1eradios_2ghz_thermal_duty_cycle\x18\xca\x01 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x1aradios2ghzThermalDutyCycle\x12`\n\x1eradios_5ghz_thermal_duty_cycle\x18\xcb\x01 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x1aradios5ghzThermalDutyCycle\x12o\n%radios_2ghz_thermal_throttled_seconds\x18\xcc\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR!radios2ghzThermalThrottledSeconds\x12o\n%radios_5ghz_thermal_throttled_seconds\x18\xcd\x01 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR!radios5ghzThermalThrottledSeconds\x12S\n\x17ifaces_lan_eth_rx_bytes\x18\xac\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x13ifacesLanEthRxBytes\x12W\n\x19ifaces_lan_eth_rx_packets\x18\xad\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x15ifacesLanEthRxPackets\x12U\n\x18ifaces_lan_eth_rx_errors\x18\xae\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x14ifacesLanEthRxErrors\x12`\n\x1eifaces_lan_eth_rx_frame_errors\x18\xaf\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x19ifacesLanEthRxFrameErrors\x12S\n\x17ifaces_lan_eth_tx_bytes\x18\xb0\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x13ifacesLanEthTxBytes\x12W\n\x19ifaces_lan_eth_tx_packets\x18\xb1\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x15ifacesLanEthTxPackets\x12U\n\x18ifaces_lan_eth_tx_errors\x18\xb2\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x14ifacesLanEthTxErrors\x12S\n\x17ifaces_wan_eth_rx_bytes\x18\xb3\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x13ifacesWanEthRxBytes\x12W\n\x19ifaces_wan_eth_rx_packets\x18\xb4\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x15ifacesWanEthRxPackets\x12U\n\x18ifaces_wan_eth_rx_errors\x18\xb5\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x14ifacesWanEthRxErrors\x12`\n\x1eifaces_wan_eth_rx_frame_errors\x18\xb6\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x19ifacesWanEthRxFrameErrors\x12S\n\x17ifaces_wan_eth_tx_bytes\x18\xb7\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x13ifacesWanEthTxBytes\x12W\n\x19ifaces_wan_eth_tx_packets\x18\xb8\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x15ifacesWanEthTxPackets\x12U\n\x18ifaces_wan_eth_tx_errors\x18\xb9\x02 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x14ifacesWanEthTxErrors\x12\x37\n\x07\x63lients\x18\x90\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x07\x63lients\x12@\n\x0c\x63lients_2ghz\x18\x91\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x0b\x63lients2ghz\x12@\n\x0c\x63lients_5ghz\x18\x92\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x0b\x63lients5ghz\x12>\n\x0b\x63lients_eth\x18\x93\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\nclientsEth\x12H\n\x10\x63lients_repeater\x18\x94\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x0f\x63lientsRepeater\x12Q\n\x15\x63lients_repeater_2ghz\x18\x95\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x13\x63lientsRepeater2ghz\x12Q\n\x15\x63lients_repeater_5ghz\x18\x96\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x13\x63lientsRepeater5ghz\x12O\n\x14\x63lients_repeater_eth\x18\x97\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x12\x63lientsRepeaterEth\x12:\n\tmesh_hops\x18\x98\x03 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x08meshHops\x12W\n\x1amesh_one_hop_rssi_avg_2ghz\x18\x99\x03 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x15meshOneHopRssiAvg2ghz\x12W\n\x1amesh_one_hop_rssi_avg_5ghz\x18\x9a\x03 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x15meshOneHopRssiAvg5ghz\x12W\n\x1amesh_two_hop_rssi_avg_2ghz\x18\x9b\x03 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x15meshTwoHopRssiAvg2ghz\x12W\n\x1amesh_two_hop_rssi_avg_5ghz\x18\x9c\x03 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x15meshTwoHopRssiAvg5ghz\x12\x65\n!ping_seconds_since_last_1s_outage\x18\xd8\x04 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x1cpingSecondsSinceLast1sOutage\x12\x65\n!ping_seconds_since_last_2s_outage\x18\xd9\x04 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x1cpingSecondsSinceLast2sOutage\x12\x65\n!ping_seconds_since_last_5s_outage\x18\xda\x04 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x1cpingSecondsSinceLast5sOutage\x12g\n\"ping_seconds_since_last_60s_outage\x18\xdb\x04 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x1dpingSecondsSinceLast60sOutage\x12i\n#ping_seconds_since_last_300s_outage\x18\xdc\x04 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x1epingSecondsSinceLast300sOutage\x12\x42\n\x0eping_drop_rate\x18\xdd\x04 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x0cpingDropRate\x12P\n\x16ping_drop_rate_last_1h\x18\xde\x04 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x12pingDropRateLast1h\x12?\n\x0cping_latency\x18\xdf\x04 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x0bpingLatency\x12n\n&ping_dish_seconds_since_last_1s_outage\x18\xe2\x04 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR pingDishSecondsSinceLast1sOutage\x12n\n&ping_dish_seconds_since_last_2s_outage\x18\xe3\x04 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR pingDishSecondsSinceLast2sOutage\x12n\n&ping_dish_seconds_since_last_5s_outage\x18\xe4\x04 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR pingDishSecondsSinceLast5sOutage\x12p\n\'ping_dish_seconds_since_last_60s_outage\x18\xe5\x04 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR!pingDishSecondsSinceLast60sOutage\x12r\n(ping_dish_seconds_since_last_300s_outage\x18\xe6\x04 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\"pingDishSecondsSinceLast300sOutage\x12K\n\x13ping_dish_drop_rate\x18\xe7\x04 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x10pingDishDropRate\x12Y\n\x1bping_dish_drop_rate_last_1h\x18\xe8\x04 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x16pingDishDropRateLast1h\x12H\n\x11ping_dish_latency\x18\xe9\x04 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x0fpingDishLatency\x12n\n%client_speedtest_router_download_mbps\x18\xbc\x05 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR!clientSpeedtestRouterDownloadMbps\x12j\n#client_speedtest_router_upload_mbps\x18\xbd\x05 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x1f\x63lientSpeedtestRouterUploadMbps\x12]\n\x1c\x63lient_speedtest_router_rssi\x18\xbe\x05 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x19\x63lientSpeedtestRouterRssi\x12j\n#client_speedtest_wifi_download_mbps\x18\xbf\x05 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x1f\x63lientSpeedtestWifiDownloadMbps\x12\x66\n!client_speedtest_wifi_upload_mbps\x18\xc0\x05 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x1d\x63lientSpeedtestWifiUploadMbps\x12n\n%client_speedtest_client_download_mbps\x18\xc1\x05 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR!clientSpeedtestClientDownloadMbps\x12j\n#client_speedtest_client_upload_mbps\x18\xc2\x05 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x1f\x63lientSpeedtestClientUploadMbps\x12]\n\x1c\x63lient_speedtest_client_rssi\x18\xc3\x05 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x19\x63lientSpeedtestClientRssi\x12`\n\x1d\x63lient_speedtest_client_iface\x18\xc4\x05 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x1a\x63lientSpeedtestClientIface\x12\\\n\x1b\x63lient_speedtest_client_oui\x18\xc5\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValueR\x18\x63lientSpeedtestClientOui\x12\x63\n\x1f\x63lient_speedtest_client_tx_rate\x18\xc6\x05 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x1b\x63lientSpeedtestClientTxRate\x12\x63\n\x1f\x63lient_speedtest_client_rx_rate\x18\xc7\x05 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\x1b\x63lientSpeedtestClientRxRate\x12o\n%client_speedtest_client_platform_type\x18\xc8\x05 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR!clientSpeedtestClientPlatformType\x12\x65\n!speedtest_tcp_8_download_mbps_avg\x18\xa0\x06 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x1cspeedtestTcp8DownloadMbpsAvg\x12\x65\n!speedtest_tcp_8_download_mbps_max\x18\xa1\x06 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x1cspeedtestTcp8DownloadMbpsMax\x12\x61\n\x1fspeedtest_tcp_8_upload_mbps_avg\x18\xa2\x06 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x1aspeedtestTcp8UploadMbpsAvg\x12\x61\n\x1fspeedtest_tcp_8_upload_mbps_max\x18\xa3\x06 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x1aspeedtestTcp8UploadMbpsMax\x12g\n\"speedtest_tcp_64_download_mbps_avg\x18\xa4\x06 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x1dspeedtestTcp64DownloadMbpsAvg\x12g\n\"speedtest_tcp_64_download_mbps_max\x18\xa5\x06 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x1dspeedtestTcp64DownloadMbpsMax\x12\x63\n speedtest_tcp_64_upload_mbps_avg\x18\xa6\x06 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x1bspeedtestTcp64UploadMbpsAvg\x12\x63\n speedtest_tcp_64_upload_mbps_max\x18\xa7\x06 \x01(\x0b\x32\x1b.google.protobuf.FloatValueR\x1bspeedtestTcp64UploadMbpsMax\x12?\n\x0c\x64ish_cell_id\x18\x84\x07 \x01(\x0b\x32\x1c.google.protobuf.UInt32ValueR\ndishCellId\x12O\n\x15\x63onfig_setup_complete\x18\xe8\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValueR\x13\x63onfigSetupComplete\x12I\n\x12\x63onfig_bands_split\x18\xe9\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValueR\x10\x63onfigBandsSplit\x12I\n\x12\x63onfig_is_repeater\x18\xea\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValueR\x10\x63onfigIsRepeater\x12K\n\x13\x63onfig_open_network\x18\xeb\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValueR\x11\x63onfigOpenNetwork\x12I\n\x12\x63onfig_is_aviation\x18\xec\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValueR\x10\x63onfigIsAviation\x12G\n\x11\x63onfig_secure_dns\x18\xed\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValueR\x0f\x63onfigSecureDns\x12@\n\rconfig_legacy\x18\xee\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValueR\x0c\x63onfigLegacy\x12\x41\n\x0e\x63onfig_ap_mode\x18\xef\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValueR\x0c\x63onfigApMode\x12I\n\x12\x63onfig_dfs_enabled\x18\xf0\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValueR\x10\x63onfigDfsEnabled\x12_\n\x1e\x63onfig_network_name_is_default\x18\xf1\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValueR\x1a\x63onfigNetworkNameIsDefault\x12Z\n\x19\x63onfig_remote_ssh_enabled\x18\xf2\x07 \x01(\x0b\x32\x1a.google.protobuf.BoolValueB\x02\x18\x01R\x16\x63onfigRemoteSshEnabled\"\x16\n\x14WifiGuestInfoRequest\"\xfc\x01\n\x15WifiGuestInfoResponse\x12\x19\n\x08is_guest\x18\x01 \x01(\x08R\x07isGuest\x12\x1b\n\tis_online\x18\x02 \x01(\x08R\x08isOnline\x12\x36\n\x17router_hardware_version\x18\x03 \x01(\tR\x15routerHardwareVersion\x12\x32\n\x15\x64ish_hardware_version\x18\x04 \x01(\tR\x13\x64ishHardwareVersion\x12?\n\x1cis_router_aviation_conformed\x18\x05 \x01(\x08R\x19isRouterAviationConformed\"\xa1\x02\n\x1dWifiFactoryTestCommandRequest\x12I\n\x0eiwpriv_command\x18\x01 \x01(\x0b\x32 .SpaceX.API.Device.IwprivCommandH\x00R\riwprivCommand\x12T\n\x13ip_link_set_command\x18\x02 \x01(\x0b\x32#.SpaceX.API.Device.IpLinkSetCommandH\x00R\x10ipLinkSetCommand\x12T\n\x13ip_addr_set_command\x18\x03 \x01(\x0b\x32#.SpaceX.API.Device.IpAddrSetCommandH\x00R\x10ipAddrSetCommandB\t\n\x07\x63ommand\"<\n\x1eWifiFactoryTestCommandResponse\x12\x1a\n\x08response\x18\x01 \x01(\tR\x08response\"\xc9\x01\n\rIwprivCommand\x12\x14\n\x05iface\x18\x01 \x01(\tR\x05iface\x12\x10\n\x03\x61rg\x18\x02 \x01(\tR\x03\x61rg\x12<\n\x05ioctl\x18\x03 \x01(\x0e\x32&.SpaceX.API.Device.IwprivCommand.IoctlR\x05ioctl\"R\n\x05Ioctl\x12\r\n\tIOCTL_SET\x10\x00\x12\r\n\tIOCTL_E2P\x10\x01\x12\r\n\tIOCTL_MAC\x10\x03\x12\x1c\n\x18IOCTL_SX_ALLOW_5GHZ_HIGH\x10\x04\"8\n\x10IpLinkSetCommand\x12\x14\n\x05iface\x18\x01 \x01(\tR\x05iface\x12\x0e\n\x02up\x18\x02 \x01(\x08R\x02up\"N\n\x10IpAddrSetCommand\x12\x14\n\x05iface\x18\x01 \x01(\tR\x05iface\x12\x10\n\x03\x61\x64\x64\x18\x02 \x01(\x08R\x03\x61\x64\x64\x12\x12\n\x04\x63idr\x18\x03 \x01(\tR\x04\x63idr\"5\n\x1fWifiStartLocalTelemProxyRequest\x12\x12\n\x04port\x18\x01 \x01(\x05R\x04port\"\x1a\n\x18WifiBackhaulStatsRequest\"\xf0\x01\n\x19WifiBackhaulStatsResponse\x12\x18\n\x07success\x18\x01 \x01(\x08R\x07success\x12\x14\n\x05\x62ssid\x18\x02 \x01(\tR\x05\x62ssid\x12\x32\n\x05iface\x18\x03 \x01(\x0e\x32\x1c.SpaceX.API.Device.IfaceTypeR\x05iface\x12\x1e\n\npreference\x18\x04 \x01(\rR\npreference\x12O\n\x0esiteSurveyScan\x18\x05 \x03(\x0b\x32\'.SpaceX.API.Device.WifiSiteSurveyResultR\x0esiteSurveyScan\"8\n\x1eWifiToggleUmbilicalModeRequest\x12\x16\n\x06\x65nable\x18\x01 \x01(\x08R\x06\x65nable2\\\n\x04Mesh\x12T\n\nMeshStream\x12\x1f.SpaceX.API.Device.ToController\x1a!.SpaceX.API.Device.FromController(\x01\x30\x01\x42\xd3\x01\n\x15\x63om.SpaceX.API.DeviceB\tWifiProtoP\x01ZIgithub.com/Eitol/starlink-client/libs/golang/client/gen/spacex/api/device\xa2\x02\x03SAD\xaa\x02\x11SpaceX.API.Device\xca\x02\x11SpaceX\\API\\Device\xe2\x02\x1dSpaceX\\API\\Device\\GPBMetadata\xea\x02\x13SpaceX::API::Deviceb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'spacex.api.device.wifi_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\025com.SpaceX.API.DeviceB\tWifiProtoP\001ZIgithub.com/Eitol/starlink-client/libs/golang/client/gen/spacex/api/device\242\002\003SAD\252\002\021SpaceX.API.Device\312\002\021SpaceX\\API\\Device\342\002\035SpaceX\\API\\Device\\GPBMetadata\352\002\023SpaceX::API::Device'
  _globals['_FROMCONTROLLER'].fields_by_name['steer_client_request']._loaded_options = None
  _globals['_FROMCONTROLLER'].fields_by_name['steer_client_request']._serialized_options = b'\030\001'
  _globals['_STEERCLIENTREQUEST_STEERTARGET'].fields_by_name['bssid']._loaded_options = None
  _globals['_STEERCLIENTREQUEST_STEERTARGET'].fields_by_name['bssid']._serialized_options = b'\030\001'
  _globals['_STEERCLIENTREQUEST_STEERTARGET'].fields_by_name['channel']._loaded_options = None
  _globals['_STEERCLIENTREQUEST_STEERTARGET'].fields_by_name['channel']._serialized_options = b'\030\001'
  _globals['_STEERCLIENTREQUEST'].fields_by_name['client_mac_addr']._loaded_options = None
  _globals['_STEERCLIENTREQUEST'].fields_by_name['client_mac_addr']._serialized_options = b'\030\001'
  _globals['_STEERCLIENTREQUEST'].fields_by_name['targets']._loaded_options = None
  _globals['_STEERCLIENTREQUEST'].fields_by_name['targets']._serialized_options = b'\030\001'
  _globals['_STEERCLIENTREQUEST']._loaded_options = None
  _globals['_STEERCLIENTREQUEST']._serialized_options = b'\030\001'
  _globals['_WIFIGETCLIENTHISTORYREQUEST'].fields_by_name['mac_address']._loaded_options = None
  _globals['_WIFIGETCLIENTHISTORYREQUEST'].fields_by_name['mac_address']._serialized_options = b'\030\001'
  _globals['_WIFIGETSTATUSRESPONSE'].fields_by_name['rf_2ghz_status']._loaded_options = None
  _globals['_WIFIGETSTATUSRESPONSE'].fields_by_name['rf_2ghz_status']._serialized_options = b'\030\001'
  _globals['_WIFIGETSTATUSRESPONSE'].fields_by_name['rf_5ghz_status']._loaded_options = None
  _globals['_WIFIGETSTATUSRESPONSE'].fields_by_name['rf_5ghz_status']._serialized_options = b'\030\001'
  _globals['_PINGMETRICS'].fields_by_name['latency_mean_ms_1d']._loaded_options = None
  _globals['_PINGMETRICS'].fields_by_name['latency_mean_ms_1d']._serialized_options = b'\030\001'
  _globals['_RADIOSTATS_THERMALSTATUS'].fields_by_name['temp']._loaded_options = None
  _globals['_RADIOSTATS_THERMALSTATUS'].fields_by_name['temp']._serialized_options = b'\030\001'
  _globals['_WIFISETCLIENTGIVENNAMEREQUEST'].fields_by_name['client_name']._loaded_options = None
  _globals['_WIFISETCLIENTGIVENNAMEREQUEST'].fields_by_name['client_name']._serialized_options = b'\030\001'
  _globals['_STARLINK_ROUTER_HOURLY_METRICS_V2'].fields_by_name['config_remote_ssh_enabled']._loaded_options = None
  _globals['_STARLINK_ROUTER_HOURLY_METRICS_V2'].fields_by_name['config_remote_ssh_enabled']._serialized_options = b'\030\001'
  _globals['_WIFICLIENTS']._serialized_start=235
  _globals['_WIFICLIENTS']._serialized_end=305
  _globals['_TOCONTROLLER']._serialized_start=308
  _globals['_TOCONTROLLER']._serialized_end=617
  _globals['_WIFIMESHJOIN']._serialized_start=620
  _globals['_WIFIMESHJOIN']._serialized_end=838
  _globals['_WIFIMESHSTATUS']._serialized_start=841
  _globals['_WIFIMESHSTATUS']._serialized_end=1241
  _globals['_MESHSPEEDTESTREQUEST']._serialized_start=1243
  _globals['_MESHSPEEDTESTREQUEST']._serialized_end=1265
  _globals['_MESHSPEEDTEST']._serialized_start=1268
  _globals['_MESHSPEEDTEST']._serialized_end=1445
  _globals['_WIFISITESURVEYRESULT']._serialized_start=1448
  _globals['_WIFISITESURVEYRESULT']._serialized_end=1780
  _globals['_WIFIGLOBALMESHSTATUS']._serialized_start=1783
  _globals['_WIFIGLOBALMESHSTATUS']._serialized_end=1962
  _globals['_BACKHAULREQUEST']._serialized_start=1964
  _globals['_BACKHAULREQUEST']._serialized_end=2082
  _globals['_FROMCONTROLLER']._serialized_start=2085
  _globals['_FROMCONTROLLER']._serialized_end=2617
  _globals['_STEERCLIENTREQUEST']._serialized_start=2620
  _globals['_STEERCLIENTREQUEST']._serialized_end=2840
  _globals['_STEERCLIENTREQUEST_STEERTARGET']._serialized_start=2767
  _globals['_STEERCLIENTREQUEST_STEERTARGET']._serialized_end=2836
  _globals['_WIFIBTMREQUEST']._serialized_start=2843
  _globals['_WIFIBTMREQUEST']._serialized_end=3156
  _globals['_WIFIBTMREQUEST_NEIGHBORREPORT']._serialized_start=3044
  _globals['_WIFIBTMREQUEST_NEIGHBORREPORT']._serialized_end=3108
  _globals['_WIFISELFTEST']._serialized_start=3159
  _globals['_WIFISELFTEST']._serialized_end=3581
  _globals['_WIFISELFTEST_TESTRESULT']._serialized_start=3484
  _globals['_WIFISELFTEST_TESTRESULT']._serialized_end=3581
  _globals['_WIFISETCONFIGREQUEST']._serialized_start=3583
  _globals['_WIFISETCONFIGREQUEST']._serialized_end=3669
  _globals['_WIFISETCONFIGRESPONSE']._serialized_start=3671
  _globals['_WIFISETCONFIGRESPONSE']._serialized_end=3773
  _globals['_WIFIGETCONFIGREQUEST']._serialized_start=3775
  _globals['_WIFIGETCONFIGREQUEST']._serialized_end=3797
  _globals['_WIFIGETCONFIGRESPONSE']._serialized_start=3799
  _globals['_WIFIGETCONFIGRESPONSE']._serialized_end=3886
  _globals['_WIFISETMESHDEVICETRUSTREQUEST']._serialized_start=3888
  _globals['_WIFISETMESHDEVICETRUSTREQUEST']._serialized_end=3997
  _globals['_WIFISETMESHDEVICETRUSTRESPONSE']._serialized_start=3999
  _globals['_WIFISETMESHDEVICETRUSTRESPONSE']._serialized_end=4031
  _globals['_WIFISETMESHCONFIGREQUEST']._serialized_start=4033
  _globals['_WIFISETMESHCONFIGREQUEST']._serialized_end=4152
  _globals['_WIFISETMESHCONFIGRESPONSE']._serialized_start=4154
  _globals['_WIFISETMESHCONFIGRESPONSE']._serialized_end=4181
  _globals['_WIFIGETCLIENTSREQUEST']._serialized_start=4183
  _globals['_WIFIGETCLIENTSREQUEST']._serialized_end=4206
  _globals['_WIFIGETCLIENTSRESPONSE']._serialized_start=4209
  _globals['_WIFIGETCLIENTSRESPONSE']._serialized_end=4367
  _globals['_WIFIGETCLIENTHISTORYREQUEST']._serialized_start=4369
  _globals['_WIFIGETCLIENTHISTORYREQUEST']._serialized_end=4464
  _globals['_WIFIGETCLIENTHISTORYRESPONSE']._serialized_start=4467
  _globals['_WIFIGETCLIENTHISTORYRESPONSE']._serialized_end=4890
  _globals['_WIFIGETCLIENTHISTORYRESPONSE_WIFILIMITEDREASON']._serialized_start=4785
  _globals['_WIFIGETCLIENTHISTORYRESPONSE_WIFILIMITEDREASON']._serialized_end=4890
  _globals['_WIFISETAVIATIONCONFORMEDREQUEST']._serialized_start=4892
  _globals['_WIFISETAVIATIONCONFORMEDREQUEST']._serialized_end=4925
  _globals['_WIFIGETHISTORYRESPONSE']._serialized_start=4928
  _globals['_WIFIGETHISTORYRESPONSE']._serialized_end=5058
  _globals['_WIFINEWCLIENTCONNECTEDEVENT']._serialized_start=5060
  _globals['_WIFINEWCLIENTCONNECTEDEVENT']._serialized_end=5144
  _globals['_WIFICLIENT']._serialized_start=5147
  _globals['_WIFICLIENT']._serialized_end=8661
  _globals['_WIFICLIENT_RXSTATS']._serialized_start=7042
  _globals['_WIFICLIENT_RXSTATS']._serialized_end=7563
  _globals['_WIFICLIENT_TXSTATS']._serialized_start=7566
  _globals['_WIFICLIENT_TXSTATS']._serialized_end=7936
  _globals['_WIFICLIENT_PINGMETRICS']._serialized_start=7939
  _globals['_WIFICLIENT_PINGMETRICS']._serialized_end=8107
  _globals['_WIFICLIENT_FQCODELINFO']._serialized_start=8110
  _globals['_WIFICLIENT_FQCODELINFO']._serialized_end=8514
  _globals['_WIFICLIENT_INTERFACE']._serialized_start=8516
  _globals['_WIFICLIENT_INTERFACE']._serialized_end=8593
  _globals['_WIFICLIENT_ROLE']._serialized_start=8595
  _globals['_WIFICLIENT_ROLE']._serialized_end=8661
  _globals['_WIFISETUPREQUEST']._serialized_start=8664
  _globals['_WIFISETUPREQUEST']._serialized_end=8804
  _globals['_WIFISETUPRESPONSE']._serialized_start=8806
  _globals['_WIFISETUPRESPONSE']._serialized_end=8825
  _globals['_WIFIBANDSTATUS']._serialized_start=8828
  _globals['_WIFIBANDSTATUS']._serialized_end=9105
  _globals['_WIFIALERTS']._serialized_start=9108
  _globals['_WIFIALERTS']._serialized_end=10101
  _globals['_WIFIGETSTATUSRESPONSE']._serialized_start=10104
  _globals['_WIFIGETSTATUSRESPONSE']._serialized_end=11714
  _globals['_WIFIAUTHENTICATEREQUEST']._serialized_start=11716
  _globals['_WIFIAUTHENTICATEREQUEST']._serialized_end=11802
  _globals['_WIFIAUTHENTICATERESPONSE']._serialized_start=11805
  _globals['_WIFIAUTHENTICATERESPONSE']._serialized_end=11947
  _globals['_WIFIACCOUNTBONDINGEVENT']._serialized_start=11949
  _globals['_WIFIACCOUNTBONDINGEVENT']._serialized_end=12075
  _globals['_WIFINEWPEEREVENT']._serialized_start=12077
  _globals['_WIFINEWPEEREVENT']._serialized_end=12120
  _globals['_PINGMETRICS']._serialized_start=12123
  _globals['_PINGMETRICS']._serialized_end=13072
  _globals['_WIFIGETPINGMETRICSREQUEST']._serialized_start=13074
  _globals['_WIFIGETPINGMETRICSREQUEST']._serialized_end=13101
  _globals['_WIFIGETPINGMETRICSRESPONSE']._serialized_start=13103
  _globals['_WIFIGETPINGMETRICSRESPONSE']._serialized_end=13191
  _globals['_WIFINETWORK']._serialized_start=13194
  _globals['_WIFINETWORK']._serialized_end=13416
  _globals['_WIFINETWORK_BAND']._serialized_start=13360
  _globals['_WIFINETWORK_BAND']._serialized_end=13416
  _globals['_WIFIPERSISTENTSTATS']._serialized_start=13419
  _globals['_WIFIPERSISTENTSTATS']._serialized_end=14062
  _globals['_WIFIPERSISTENTSTATS_EVENT']._serialized_start=13977
  _globals['_WIFIPERSISTENTSTATS_EVENT']._serialized_end=14062
  _globals['_WIFIGETPERSISTENTSTATSRESPONSE']._serialized_start=14064
  _globals['_WIFIGETPERSISTENTSTATSRESPONSE']._serialized_end=14158
  _globals['_RADIOSTATS']._serialized_start=14161
  _globals['_RADIOSTATS']._serialized_end=14804
  _globals['_RADIOSTATS_THERMALSTATUS']._serialized_start=14544
  _globals['_RADIOSTATS_THERMALSTATUS']._serialized_end=14699
  _globals['_RADIOSTATS_ANTENNASTATUS']._serialized_start=14701
  _globals['_RADIOSTATS_ANTENNASTATUS']._serialized_end=14804
  _globals['_STARLINK_ROUTERS_HOURLY_METRICS_V2']._serialized_start=14808
  _globals['_STARLINK_ROUTERS_HOURLY_METRICS_V2']._serialized_end=35658
  _globals['_STARLINK_ROUTER_ALERTS']._serialized_start=35661
  _globals['_STARLINK_ROUTER_ALERTS']._serialized_end=35897
  _globals['_STARLINK_ROUTER_CLIENT_SPEEDTESTS']._serialized_start=35900
  _globals['_STARLINK_ROUTER_CLIENT_SPEEDTESTS']._serialized_end=38429
  _globals['_STARLINKROUTERCLIENTS']._serialized_start=38432
  _globals['_STARLINKROUTERCLIENTS']._serialized_end=40535
  _globals['_WIFISETCLIENTGIVENNAMEREQUEST']._serialized_start=40538
  _globals['_WIFISETCLIENTGIVENNAMEREQUEST']._serialized_end=40707
  _globals['_WIFISELFTESTREQUEST']._serialized_start=40709
  _globals['_WIFISELFTESTREQUEST']._serialized_end=40730
  _globals['_WIFISELFTESTRESPONSE']._serialized_start=40732
  _globals['_WIFISELFTESTRESPONSE']._serialized_end=40836
  _globals['_WIFIRUNSELFTESTREQUEST']._serialized_start=40838
  _globals['_WIFIRUNSELFTESTREQUEST']._serialized_end=40862
  _globals['_WIFIRFTESTREQUEST']._serialized_start=40865
  _globals['_WIFIRFTESTREQUEST']._serialized_end=41248
  _globals['_WIFIRFTESTRESPONSE']._serialized_start=41250
  _globals['_WIFIRFTESTRESPONSE']._serialized_end=41294
  _globals['_WIFIGETFIREWALLREQUEST']._serialized_start=41296
  _globals['_WIFIGETFIREWALLREQUEST']._serialized_end=41320
  _globals['_WIFIGETFIREWALLRESPONSE']._serialized_start=41322
  _globals['_WIFIGETFIREWALLRESPONSE']._serialized_end=41406
  _globals['_WIFITOGGLEPOENEGOTIATIONREQUEST']._serialized_start=41408
  _globals['_WIFITOGGLEPOENEGOTIATIONREQUEST']._serialized_end=41465
  _globals['_WIFICALIBRATIONMODEREQUEST']._serialized_start=41467
  _globals['_WIFICALIBRATIONMODEREQUEST']._serialized_end=41495
  _globals['_STARLINK_ROUTER_HOURLY_METRICS_V2']._serialized_start=41498
  _globals['_STARLINK_ROUTER_HOURLY_METRICS_V2']._serialized_end=53319
  _globals['_WIFIGUESTINFOREQUEST']._serialized_start=53321
  _globals['_WIFIGUESTINFOREQUEST']._serialized_end=53343
  _globals['_WIFIGUESTINFORESPONSE']._serialized_start=53346
  _globals['_WIFIGUESTINFORESPONSE']._serialized_end=53598
  _globals['_WIFIFACTORYTESTCOMMANDREQUEST']._serialized_start=53601
  _globals['_WIFIFACTORYTESTCOMMANDREQUEST']._serialized_end=53890
  _globals['_WIFIFACTORYTESTCOMMANDRESPONSE']._serialized_start=53892
  _globals['_WIFIFACTORYTESTCOMMANDRESPONSE']._serialized_end=53952
  _globals['_IWPRIVCOMMAND']._serialized_start=53955
  _globals['_IWPRIVCOMMAND']._serialized_end=54156
  _globals['_IWPRIVCOMMAND_IOCTL']._serialized_start=54074
  _globals['_IWPRIVCOMMAND_IOCTL']._serialized_end=54156
  _globals['_IPLINKSETCOMMAND']._serialized_start=54158
  _globals['_IPLINKSETCOMMAND']._serialized_end=54214
  _globals['_IPADDRSETCOMMAND']._serialized_start=54216
  _globals['_IPADDRSETCOMMAND']._serialized_end=54294
  _globals['_WIFISTARTLOCALTELEMPROXYREQUEST']._serialized_start=54296
  _globals['_WIFISTARTLOCALTELEMPROXYREQUEST']._serialized_end=54349
  _globals['_WIFIBACKHAULSTATSREQUEST']._serialized_start=54351
  _globals['_WIFIBACKHAULSTATSREQUEST']._serialized_end=54377
  _globals['_WIFIBACKHAULSTATSRESPONSE']._serialized_start=54380
  _globals['_WIFIBACKHAULSTATSRESPONSE']._serialized_end=54620
  _globals['_WIFITOGGLEUMBILICALMODEREQUEST']._serialized_start=54622
  _globals['_WIFITOGGLEUMBILICALMODEREQUEST']._serialized_end=54678
  _globals['_MESH']._serialized_start=54680
  _globals['_MESH']._serialized_end=54772
# @@protoc_insertion_point(module_scope)
